%macro abshmast;

options &mprint &source &notes;

%let table=hcmdata.abshist;

%deltable(tables=keys abshist abshmast absmast1 absmast2 absmast3 absmast4 absmast5 absmast9);

options metarepository="&HRRepos";
%LibConOp(sesetl_sasLibRef=HCMDATA,
         sesetl_ChkDepRepos=Y
         ) ;
proc sql;
    connect to &sesetl_EngineType as PASSTHRU
               (&sesetl_BestLogin &sesetl_ConnectionOptions );
       execute(drop table if exists abshmast
               ) by PASSTHRU;
    disconnect from PASSTHRU;
QUIT;

%let basekeys=&abshkeys;
%let joinkeys=employee_id job_cd &hiers;
proc sort data=&table out=abshist;
  by &basekeys;
  where absence_start_dt le "&bldctoff"d;
run;


/* build the initial keys data set */
%joinkeys(basetabl=abshist,basekeys=&basekeys,joinkeys=&joinkeys,init=Y);

/* join this with ACTHIST to pick additional keys information */
%hrjoin(table=absmast9,base=keys,basejvar=employee_id,
        join=hcmdata.acthist,joinjvar=employee_id,
        basekey=&basekeys,basedate=absence_start_dt,joindate=action_dt,dropvars=&acthistm _lastrec,
        eedtevar=valid_to_dttm);

/* see if we need to pick up additional keys from acthist */
/* note, that we are not joining to acthist later in this program.  */
/* this is strictly to pick up additional keys */
%joinkeys(basetabl=absmast9,basekeys=&basekeys,joinkeys=&joinkeys);


/* join in position information */
%hrjoin(table=absmast1,base=keys,basejvar=employee_id,
        join=hcmdata.pos,joinjvar=employee_id,
        basekey=&basekeys,basedate=absence_start_dt,joindate=valid_from_dttm,
        dropvars=&posm job_cd _lastrec,eedtevar=valid_to_dttm);


/* see if we need to pick up additional keys from pos */
%joinkeys(basetabl=absmast1,basekeys=&basekeys,joinkeys=&joinkeys);

/* join in job information */
%hrjoin(table=absmast2,base=keys,basejvar=job_cd,
        join=hcmdata.jobs,joinjvar=job_cd,
        basekey=&basekeys,basedate=absence_start_dt,joindate=valid_from_dttm,
        dropvars=&jobsm  _lastrec,eedtevar=valid_to_dttm);

/* see if we need to pick up additional keys from jobs */
%joinkeys(basetabl=absmast2,basekeys=&basekeys,joinkeys=&joinkeys);


/* join in hierarchy information */
data keyshr(drop=job_cd);
      set keys;run;
%grphiers(baseds=keyshr,grplevds=hcmdata.wrkgrp,basedate=absence_start_dt,eedtevar=VALID_TO_DT,
         hiername=hiermax,rptgrp=intorg,prntgrp=parent_intorg,mgrname=MANAGER_NAME,
         outds=rptgrphr,joindate=VALID_FROM_DT);
data absmast3;
 set rptgrphr(drop=grpdesc hierarchy_cd);
run;


/* join absence data with employee general data */
%cempgen;
%hrjoin(table=absmast4,base=keys,basejvar=employee_id,
        join=cempgen,joinjvar=employee_id,
        basekey=&basekeys,dropvars=&empgenm valid_from_dttm valid_to_dttm _lastrec);

data abshmast(sortedby=&basekeys);
  merge
    absmast4
    absmast3
    absmast2
    absmast1
    abshist(in=s)
  ;
  by &basekeys;
  if s;

  /* create date variables */
  %YRQTRMON(date=absence_start_dt,year=year,qtr=qtr,month=month,day=bday,weekday=wkday);


  /* recalculate age as of effective date */
  %AGE(basedate=absence_start_dt);

  /* calculate service years as of effective date of absence */
  %LOS(basedate=absence_start_dt);

  /* drop any additional variables */
  %DROPVAR(dropvar=abshmstv);


run;

/* clean up */
%deltable(tables=keys abshist absmast1 absmast2 absmast3 absmast4 absmast9 absmast5
          rptgrphr keyshr);

/* set _lastrec and place into final sorted order and location */
proc sort data=abshmast;by employee_id descending absence_start_dt;
data abshmast;
 set abshmast;by employee_id descending absence_start_dt;
 If first.employee_id then _lastrec='Y';
 else _lastrec='N';
 proc sort data=abshmast out=hcmdata.abshmast;
 by &absmsort;
run;

/* clean up */
%deltable(tables=abshmast);

%regrdata(sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
          sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
          sesetl_sasLibrary=hcmdata,sesetl_physicalTable=ABSHMAST);

%mend;
