%macro acthist;

options &mprint &source &notes;

options metarepository="&HRRepos";
%LibConOp(sesetl_sasLibRef=HCMDATA,
         sesetl_ChkDepRepos=Y
         ) ;
proc sql;
    connect to &sesetl_EngineType as PASSTHRU
               (&sesetl_BestLogin &sesetl_ConnectionOptions );
       execute(drop table if exists acthist
               ) by PASSTHRU;
    disconnect from PASSTHRU;
QUIT;


/* make sure work library has no current copies of the needed work datasets */
%deltable(tables=acthist acthist1 acthist2 acthist3 acthist4 employee employee_action temp tpose job_position
                 employee_x employee_x_internal_org internal_org_x);

%let basekeys=&actdkeys;

data employee_action;
 set conform.employee_action(drop=pay_level_cd processed_dttm);
run;

data employee;
 set conform.employee(keep=valid_from_dttm valid_to_dttm fte_rt permanence_cd employee_rk
                           disciplinary_action_flg);
 valid_from_dttm=datepart(valid_from_dttm);
 valid_to_dttm=datepart(valid_to_dttm);
run;

/* Join the Employee and Employee Action tables */
%hrjoin(table= acthist1,base=employee_action,basejvar=employee_rk,
        join=employee,joinjvar=employee_rk,
        basekey=&basekeys,basedate=action_dt,joindate=valid_from_dttm,dropvars=,
        eedtevar=valid_to_dttm);


/* Join to Employee_X_job to get JOB_CD and POSITION_CD for employee  */
%hrjoin(table=acthist2,base=acthist1,basejvar=employee_rk,
        join=conform.employee_x_job,joinjvar=employee_rk,
        basekey=&basekeys,basedate=action_dt,joindate=start_dt,dropvars=processed_dttm,
        eedtevar=end_dt);

/* creating subset of conform.job_position for join. Only need FLSA_Status_CD from this table */
/* keep either open_dt or valid_from_dttm depending upon which one to use for join */
data job_position;
 set conform.job_position(keep=open_dt flsa_status_cd position_cd);
run;

/* should we be joining with conform.job_position on valid_from_dttm or open_dt? */
/* Join to Job_Position to get FLSA_Status_cd  */

%hrjoin(table=acthist3,base=acthist2,basejvar=position_cd,
        join=job_position,joinjvar=position_cd,
        basekey=&basekeys,basedate=action_dt,joindate=open_dt,dropvars=,
        eedtevar=);


/* create a temp dataset that only contains the variables needed to join to  */
/* employee_x_internal_org and for the transpose */
data temp;set acthist3;
 keep employee_rk action_dt action_type_cd;
run;
%let bk=employee_rk action_dt action_type_cd internal_org_rk internal_org_assoc_type_cd;

proc sort data=conform.employee_x_internal_org out=employee_x_internal_org;by internal_org_rk;run;
proc sort data=conform.internal_org_x out=internal_org_x;by internal_org_rk;run;

/* Add the internal_org_id to the employee_x_internal_org table */
data employee_x_internal_org(drop=internal_org_rk processed_dttm employee_x_internal_org_adk);
 merge employee_x_internal_org(in=a) internal_org_x(keep=internal_org_rk internal_org_id);
   by internal_org_rk;if a;
   valid_from_dttm=datepart(valid_from_dttm);
   valid_to_dttm=datepart(valid_to_dttm);
run;

%hrjoin(table=acthist4,base=temp,basejvar=employee_rk,
        join=employee_x_internal_org,joinjvar=employee_rk,
        basekey=&bk,basedate=action_dt,joindate=valid_from_dttm,dropvars=,
        eedtevar=valid_to_dttm);

proc transpose data=acthist4 out=tpose(drop=_name_ _label_) ;
     by employee_rk action_dt action_type_cd;
           id internal_org_assoc_type_cd;
     var internal_org_id ;
run;
/* merge the transposed dataset back with the original acthist2 dataset */
data acthist;
 merge acthist3 tpose;by employee_rk action_dt action_type_cd;

/* calculate the HOURLY, MONTHLY and ANNUAL SALARY columns */
/* the assumption is being made that the Hours_Per_Week_Cnt is populated in the DDS Employee_Action table*/
%paycalc;

drop &acthistd;

proc sort;by employee_rk;
run;

proc sort data=conform.employee_x out=employee_x;by employee_rk;run;
/* Get Employee_id and drop Employee_RK */
data acthist(drop=employee_rk);
 merge acthist(in=a) employee_x(in=b keep=employee_rk employee_id);
 by employee_rk;if a and b;
run;


%eedate(dsname=acthist,edate=action_dt,eedate=valid_to_dt,id=employee_id);
%source2(dsname=acthist,datevar=action_dt,sortids=&acthsort,
         subset=%str(where action_dt le %'&BLDCTOFF%'D;));

/* set the work dataset into the HCM MySQL table */
data hcmdata.acthist;
 length ONPAYRL $1.;
 set acthist;
run;

/* clean up */
%deltable(tables=acthist acthist1 acthist2 acthist3 acthist4 employee employee_action temp tpose job_position
                 employee_x employee_x_internal_org internal_org_x);

%regrdata(sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
          sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
          sesetl_sasLibrary=hcmdata,sesetl_physicalTable=acthist);

%mend;
