%macro acthmast;

options &mprint &source &notes;

%let table=hcmdata.acthist;

options metarepository="&HRRepos";
%LibConOp(sesetl_sasLibRef=HCMDATA,
         sesetl_ChkDepRepos=Y
         ) ;
proc sql;
    connect to &sesetl_EngineType as PASSTHRU
               (&sesetl_BestLogin &sesetl_ConnectionOptions );
       execute(drop table if exists acthmast
               ) by PASSTHRU;
    disconnect from PASSTHRU;
QUIT;

/* make sure work library has no current copies of the needed work datasets */
%deltable(tables=keys acthist actmast1 actmast2 actmast3 actmast4 actmast5 actmast6);


%let basekeys=&acthkeys;
%let joinkeys=job_cd pay_level_structure_cd position_cd &hiers;

/* create a working copy of acthist */
proc sort data=&table out=acthist;
  by &basekeys;
  where action_dt le "&bldctoff"d;
run;

/* build the initial keys data set */
%joinkeys(basetabl=acthist,basekeys=&basekeys,joinkeys=&joinkeys,init=Y);

/* join in position information */
%hrjoin(table=actmast1,base=keys,basejvar=position_cd,
        join=hcmdata.pos,joinjvar=position_cd,
        basekey=&basekeys,basedate=action_dt,joindate=valid_from_date,dropvars=&posm _lastrec,
        eedtevar=VALID_TO_DT);

/* see if we need to pick up additional keys from pos */
%joinkeys(basetabl=actmast1,basekeys=&basekeys,joinkeys=&joinkeys);


/* join in job information */
%hrjoin(table=actmast2,base=keys,basejvar=job_cd,
        join=hcmdata.jobs,joinjvar=job_cd,
        basekey=&basekeys,basedate=action_dt,joindate=valid_from_date,dropvars=&jobsm  _lastrec,
        eedtevar=VALID_TO_DT);

/* see if we need to pick up additional keys from jobs */
%joinkeys(basetabl=actmast2,basekeys=&basekeys,joinkeys=&joinkeys);

/* join in hierarchy information */
data keyshr(drop=pay_level_structure_cd position_cd job_cd);
      set keys;run;
%grphiers(baseds=keyshr,grplevds=hcmdata.wrkgrp,basedate=action_dt,eedtevar=VALID_TO_DT,
         hiername=hiermax,rptgrp=intorg,prntgrp=parent_intorg,mgrname=MANAGER_NAME,
         outds=rptgrphr,joindate=VALID_FROM_DT);
data actmast3;
 set rptgrphr(drop=grpdesc hierarchy_cd);
run;


/* join in pay grade information */
%hrjoin(table=actmast4,base=keys,basejvar=pay_level_structure_cd,
        join=hcmdata.grade,joinjvar=pay_level_structure_cd,
        basekey=&basekeys,basedate=action_dt,joindate=valid_from_fttm,dropvars=&gradem  _lastrec,
        eedtevar=VALID_TO_DT);

/* see if we need to pick up additional keys from grade */
%joinkeys(basetabl=actmast4,basekeys=&basekeys,joinkeys=&joinkeys);

/* join in employee general information */
%cempgen;
%hrjoin(table=actmast5,base=keys,basejvar=employee_id,
        join=cempgen,joinjvar=employee_id,
        basekey=&basekeys,dropvars=&empgenm  VALID_FROM_DT VALID_TO_DT _lastrec);


/* merge and add calculated fields */
data acthmast;
  merge
        actmast5
        actmast4
        actmast3
        actmast2
        actmast1
        acthist(in=s)
  ;
  by &basekeys;
  if s;

  /* full time equivalency */
  %FTEQUIV;

  /* Salary calculation, this must be referenced before other salary statisitics */
  %SALCALC;

  /* calcualate salary changes */
  /*%SALCHNG;*/

  /* compa-ratio */
  %COMRATIO;

  /* range penetration */
  %RNGPENE;

  /* percentage over max */
  %PCTOVMAX;

  /* percentage over under min */
  %PCTUNMIN

  /* create date variables */
  %YRQTRMON(date=action_dt,year=YEAR,qtr=QTR,month=MONTH);

  /*calculate age as of effective date */
  %AGE(basedate=action_dt);

  /* calculate srvyrs as of effective date  */
  %LOS(basedate=action_dt)

  /* Date in current grade */
  %DATEGRDE

  /* Date in current job code */
  %DATEJOB

   /* label for the MGRGRP column */
 /*  %MGRGRP; */

  /* this is here so the EIS multidim has something to count */
  ACTIONS=1;


  /* drop any additional variables */
  %DROPVAR(dropvar=acthmstv);
run;

/* place into final sorted order and location */
proc sort data=acthmast out=hcmdata.ACTHMAST;
  by &actmsort;
run;

/* add effective end date, if it's not already there */
%eedate(dsname=hcmdata.ACTHMAST,edate=action_dt,eedate=VALID_TO_DT,id=employee_id);

/* clean up */
%deltable(tables=keys acthist actmast1 actmast2 actmast3 actmast4 actmast5
                 keyshr rptgrphr);



/* clean up */
%deltable(tables=acthmast);

%regrdata(sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
          sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
          sesetl_sasLibrary=hcmdata,sesetl_physicalTable=ACTHMAST);

%mend;
