%macro apphmast;

options &mprint &source &notes;

%let table=hcmdata.apphist;

options metarepository="&HRRepos";
%LibConOp(sesetl_sasLibRef=HCMDATA,
         sesetl_ChkDepRepos=Y
         ) ;
proc sql;
    connect to &sesetl_EngineType as PASSTHRU
               (&sesetl_BestLogin &sesetl_ConnectionOptions );
       execute(drop table if exists apphmast
               ) by PASSTHRU;
    disconnect from PASSTHRU;
QUIT;

/* make sure work library has no current copies of the needed work datasets */
%deltable(tables=keys apphmast apphist apphist1 apphist2 apphist3);

%let basekeys=&apphkeys;
%let joinkeys=position_cd job_cd internal_org_id;

proc sort data=&table out=apphist;
  by &basekeys;
  where application_dt le "&bldctoff"d;
run;

/* build the initial keys data set */
%joinkeys(basetabl=apphist,basekeys=&basekeys,joinkeys=&joinkeys,init=Y);

/* join in positions data */
%hrjoin(table=apphist1,base=keys,basejvar=position_cd,
        join=hcmdata.pos,joinjvar=position_cd,
            basekey=&basekeys,basedate=application_dt,joindate=VALID_FROM_DT,
            dropvars=&posm  _lastrec,eedtevar=VALID_TO_DT);


/* see if we need to pick up additional keys from pos */
%joinkeys(basetabl=apphist1,basekeys=&basekeys,joinkeys=&joinkeys);

/* join in job information */
%hrjoin(table=apphist2,base=keys,basejvar=job_cd,
        join=hcmdata.jobs,joinjvar=job_cd,
        basekey=&basekeys,basedate=application_dt,joindate=VALID_FROM_DT,
        dropvars=&jobsm  _lastrec,eedtevar=VALID_TO_DT);


/* see if we need to pick up additional keys from jobs */
%joinkeys(basetabl=apphist2,basekeys=&basekeys,joinkeys=&joinkeys);

/* join in hierarchy information */
data keyshr(rename=(internal_org_id=intorg));
      set keys;run;
%grplevs(baseds=keyshr,grplevds=hcmdata.wrkgrp,basedate=application_dt,eedtevar=,
         hiername=hiermax,rptgrp=intorg,prntgrp=parent_intorg,
         outds=rptgrphr,joindate=VALID_FROM_DT,root=&default_hier,mgrname=MANAGER_NAME);
data apphist3;set rptgrphr(rename=(intorg=internal_org_id)drop=grpdesc hierarchy_cd);run;

data apphmast;
  merge
    apphist3
    apphist2
    apphist1
    apphist(in=s)
  ;
  by &basekeys;
  if s;

  /* calculate age if necessary */
  %AGECALC(dob=applicant_birth_dt,basedate=application_dt,agevar=appage,
              over40=appov40,decimal=&agefract);

  /* create date variables */
  %YRQTRMON(date=application_dt,year=year,qtr=qtr,month=month);

  /* count variable for the MDDB */
  count=1;

  /* drop any additional variables */
  %DROPVAR(dropvar=apphmstv);

run;

/* clean up */
%deltable(tables=keys apphist apphist1 apphist2 apphist3
                 keyshr rptgrphr);

/* set _lastrec and place into final sorted order and location */
data apphmast;
 set apphmast;
 _lastrec='Y';
 proc sort data=apphmast out=hcmdata.APPHMAST;by &appmsort;
run;

/* clean up */
%deltable(tables=apphmast);

%regrdata(sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
          sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
          sesetl_sasLibrary=hcmdata,sesetl_physicalTable=APPHMAST);

%mend;
