%macro EMPMAST;

options &mprint &source &notes;

%let table=hcmdata.acthist;

options metarepository="&HRRepos";
%LibConOp(sesetl_sasLibRef=HCMDATA,
         sesetl_ChkDepRepos=Y
         ) ;
proc sql;
    connect to &sesetl_EngineType as PASSTHRU
               (&sesetl_BestLogin &sesetl_ConnectionOptions );
       execute(drop table if exists empmast
               ) by PASSTHRU;
    disconnect from PASSTHRU;
QUIT;

/* make sure work library has no current copies of the needed work datasets */
%deltable(tables=empmast acthist empmast1 empmast2 empmast3 empmast4 empmast5 empmast6 openpos);


/* conditionally construct an IF statement only if EMPSTAT exists in ACTHIST */
/* whether it does or doesn't, we still have to refilter for it in the last step */
%let empwhr1=;
%let empwhr2=;

data _null_;
  if not exist("&table",'VIEW') and not exist("&table",'DATA') then stop;
  dsid=open("&table");
  if dsid gt 0 then do;
    if varnum(dsid,'employee_status_cd') then do;
      if upcase(symget("EMPPOP"))='ACTIVE' then
        call symput('EMPWHR1',"if put(employee_status_cd,$iempsta.) ne 'IN' and put(action_type_cd,$iaction.) not in
                    ('ITERM' 'VTERM');");
      call symput('EMPWHR2',"if put(employee_status_cd,$iempsta.) ne 'IN' and put(action_type_cd,$iaction.) not in
                  ('ITERM' 'VTERM') then VALID_FROM_DT=""&bldctoff""d;");
    end;
    dsid=close(dsid);
  end;
run;

%let basekeys=&empkeys;
%let joinkeys=job_cd pay_level_structure_cd position_cd &hiers;

/* ACTHIST should to be sorted, by ID EDATE, regardless of what it's original order is */
/* so that we can get the last chronological record for a given employee */
proc sort data=&table(drop=employee_action_reason_cd
                      rename=(action_dt=VALID_FROM_DT))
          out=acthist;
  by &basekeys;
  where VALID_FROM_DT le "&bldctoff"d;
run;

/* get the last record for each employee from ACTHIST */
data acthist(drop=action_type_cd);
  set acthist;
  by employee_id;
  if last.employee_id;

  /* if the macro EMPPOP is set to ACTIVE and EMPSTAT is present then get only active employees */
  &empwhr1;

  /* set the effective date to the current build date so that further merges */
  /* will be based on the build date rather than the original effective date */
  /* Do this only for active employees and only if EMPSTAT is present */
  &empwhr2;
run;

/* if necessary, join in open position data to empmast */
%macro openpos;
  %local test canwher closwher;
  %let test=%superq(incopen);
  %if %str(&test)=Y %then %do;
    %getvars(dsname=hcmdata.openpos);
    %if %str(&vars) ne %then %varshere(dsname=empmast,vars=%str(&vars));
    %if &here ne %then %do;
      %if %index(&vars,%str( CLOSDATE )) gt 0 %then
        %let closwher=%str((closdate=. or closdate gt "&bldctoff"d));
      %if %index(&vars,%str( CANDATE )) gt 0 %then
        %let canwher=%str((candate=. or candate gt "&bldctoff"d));
      data openpos;
        set hcmdata.openpos;
        edate="&bldctoff"d;
      %if &closwher ne or &canwher ne  %then %do;
        where
        %if &closwher ne %then %do;
          %str(&closwher)
          %if &canwher ne %then %str( and );
        %end;
        %if &canwher ne %then %str( &canwher );
        ;
      %end;
      %if %index(&vars,%str( OPENDATE )) gt 0 %then %str(if opendate le "&bldctoff"d;);
      %if %index(&vars,%str( ID )) gt 0 %then %str(if id=' ';);
      %else %str(id=' ';);
        keep id &here;
      run;
      data acthist;
        set acthist openpos;
        by id;
      run;
    %end;
    %let here=;%let nothere=;%let vars=;
  %end;
%mend;
%openpos;

/* build the initial keys data set */
%joinkeys(basetabl=acthist,basekeys=&basekeys,joinkeys=&joinkeys,init=Y);

/* join in position information */
%hrjoin(table=empmast1,base=keys,basejvar=position_cd,
        join=hcmdata.pos,joinjvar=position_cd,
        basekey=&basekeys,basedate=VALID_FROM_DT,joindate=VALID_FROM_DT,dropvars=&posm
        internal_org_id employee_id job_cd,
        eedtevar=VALID_TO_DT);

/* see if we need to pick up additional keys from pos */
%joinkeys(basetabl=empmast1,basekeys=&basekeys,joinkeys=&joinkeys);

/* join in job information */
%hrjoin(table=empmast2,base=keys,basejvar=job_cd,
        join=hcmdata.jobs,joinjvar=job_cd,
        basekey=&basekeys,basedate=VALID_FROM_DT,joindate=VALID_FROM_DT,dropvars=&jobsm ,
        eedtevar=VALID_TO_DT);

/* see if we need to pick up additional keys from jobs */
%joinkeys(basetabl=empmast2,basekeys=&basekeys,joinkeys=&joinkeys);

/* join in hierarchy information */
data keyshr(drop=pay_level_structure_cd position_cd job_cd);
      set keys;run;
%grphiers(baseds=keyshr,grplevds=hcmdata.wrkgrp,basedate=VALID_FROM_DT,eedtevar=VALID_TO_DT,
         hiername=hiermax,rptgrp=intorg,prntgrp=parent_intorg,mgrname=MANAGER_NAME,
         outds=rptgrphr,joindate=VALID_FROM_DT);
data empmast3;
 set rptgrphr(drop=grpdesc hierarchy_cd);
run;

/* join in pay grade information */
%hrjoin(table=empmast4,base=keys,basejvar=pay_level_structure_cd,
        join=hcmdata.grade,joinjvar=pay_level_structure_cd,
        basekey=&basekeys,basedate=VALID_FROM_DT,joindate=VALID_FROM_DT,dropvars=&gradem  _lastrec,
        eedtevar=VALID_TO_DT);

/* see if we need to pick up additional keys from grade */
%joinkeys(basetabl=empmast4,basekeys=&basekeys,joinkeys=&joinkeys);

/* join in employee general information */
%cempgen;
%hrjoin(table=empmast5,base=keys,basejvar=employee_id,
        join=cempgen,joinjvar=employee_id,
        basekey=&basekeys,
        dropvars=VALID_FROM_DT VALID_TO_DT _lastrec );

/* merge and add calculated fields */
/* add empmast6 back if needed for MGRGRP */
data empmast;
  merge

        empmast5
        empmast4
        empmast3
        empmast2
        empmast1
        acthist(in=s)
  ;
  by &basekeys;
  if s;

  /* if necessary, refilter for active only employees */
  if upcase(symget("emppop"))='ACTIVE' then if put(employee_status_cd,$iempsta.)='A';

  /*  full time equivalency */
  %FTEQUIV;

  /* Salary calculation, this must be referenced before other salary statisitics */
  %SALCALC;

  /* compa-ratio */
  %COMRATIO;

  /* range penetration */
  %RNGPENE;

  /* percentage over max */
  %PCTOVMAX;

  /* percentage over under min */
  %PCTUNMIN;

  /* recalculate current age */
  %AGE;

  /* calculate srvyrs for employees */
  %LOS;

  /* drop any additional variables */
  %DROPVAR(dropvar=empmstv);


run;

/* clean up */
%deltable(tables=acthist empmast1 empmast2 empmast3 empmast4 empmast5 empmast6 openpos
         keys keyshr rptgrphr);


/* place into final sorted order and location */
proc sort data=empmast out=hcmdata.EMPMAST;
  by &empmsort;
run;

/* clean up */
%deltable(tables=empmast);

%regrdata(sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
          sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
          sesetl_sasLibrary=hcmdata,sesetl_physicalTable=EMPMAST);

%mend;
