%macro headsum;

/* 03/2000 - new hire section added  */
/* TGL, Sheray - 02/09/2000 - restructured code such that the TERMS are built */
/* from ACTHMAST directly.  Additionaly, the final data step was split into two */
/* to make the code simpler */

options &mprint &source &notes;

options metarepository="&HRRepos";
%LibConOp(sesetl_sasLibRef=HCMDATA,
         sesetl_ChkDepRepos=Y
         ) ;
proc sql;
    connect to &sesetl_EngineType as PASSTHRU
               (&sesetl_BestLogin &sesetl_ConnectionOptions );
       execute(drop table if exists headsum
               ) by PASSTHRU;
    disconnect from PASSTHRU;
QUIT;

/* system option FMTERR must be turned off.  Store it for later so it can be set */
/* back to it's original state */
%let fmterr=%sysfunc(getoption(FMTERR));
options nofmterr;

/* TGL  3/24/99  - RPTGRP needs to be in HEADSUM, so there's at least one key */

%local keepvars i;
  %do i=1 %to &number_of_hiers;
    %let hier=%scan(&hiers, &i);
    %let hiername_temp = hiermax;
    %if &i > 1 %then %do;
       %let hiername_temp=&&hiername_temp%eval(&i-1);
        %put hiername_temp=&hiername_temp;
    %end;
    %else %do;
       %let hiername_temp=&&hiername_temp;
    %end;
        %let keepvars=&keepvars
    %classgen(prefix=&hier,maxvar=&hiername_temp);
  %end;
     %let keepvars=&keepvars
    &hedvars &hedmddbo &hedmddbh &hiers;

%let lastvar=%reverse(%scan(%reverse(&keepvars),1));
%let basekeys=employee_id action_dt;
%let joinkeys=job_cd &hiers pay_level_structure_cd position_cd;

/* delete any existing views */
%deltable(tables=hdsum hdhist hdhist1 hdhist2 hdhist3 hdhist4 hdhist5);

%let prevdate=;
/* get the anniversary before the cutoff.  Use this as the beginning */
/* so the change statistics can be calculated beginning with the cutoff date.*/
data _null_;
  hdcutoff=intnx("&hedunit","&hdcutoff"d,0,"&hedstart");
  call symput('hdcutoff',put(hdcutoff,date9.));
  prevdate=intnx("&hedunit","&hdcutoff"d,-1,"&hedstart");
  call symput('prevdate',put(prevdate,6.));
run;

/* see if EMPSTAT is in ACTHIST, if so, generate an if statement */
/* to eliminate inactive employees */
%let empwhr=;
data _null_;
  dsid=open("hcmdata.acthist");
  if dsid gt 0 then do;
    if varnum(dsid,'EMPLOYEE_STATUS_CD') gt 0 then
      call symput('EMPWHR','if put(employee_status_cd,$iempsta.) ne "IN";');
  end;
run;

/* get the appropriate acthist records, calculate cutoff anniversary dates */
data hdhist;
  set hcmdata.acthist(drop=&acthistm employee_action_reason_cd
                      where=(action_dt ne . and action_dt le "&bldctoff"d and
                             put (action_type_cd,$iaction.) not in ('ITERM' 'VTERM'))
                     );


  /* take care of the problem that the dates might not be integers */
  if action_dt ne . then action_dt=int(action_dt);
  if VALID_TO_DT ne . then VALID_TO_DT=int(VALID_TO_DT);

  /* create a working eedate */
  if VALID_TO_DT=. or VALID_TO_DT gt "&bldctoff"d then w_eedate="&bldctoff"d;
  else w_eedate=VALID_TO_DT;
  drop w_eedate;

  /* get the anniversay just before eedate */
  eedatev=intnx("&hedunit",w_eedate,0,"&hedstart");
  if eedatev gt w_eedate then eedatev=intnx("&hedunit",w_eedate,-1,"&hedstart");
  drop eedatev;

  /* get the anniversay just after edate */
  edatev=intnx("&hedunit",action_dt,0,"&hedstart");
  if edatev lt action_dt then edatev=intnx("&hedunit",action_dt,1,"&hedstart");
  drop edatev;

  /* if this is the current record then output a current record */
  if w_eedate="&bldctoff"d then do;
    action_dt="&bldctoff"d;
    output hdhist;
  end;

  /* keep only records valid after the cutoff and before the build date */
  if eedatev ge "&hdcutoff"d and edatev le "&bldctoff"d;

  /* use the previously generated IF statement to possibly filter out inactive employees */
  &empwhr

  /* keep only records that are not on the same time unit */
  if eedatev ge edatev;

  /* reset edatev to the next anniversary after/equal to the cutoff */
  edatev=max(edatev,"&hdcutoff"d);

  /* reset eedatev to the anniversary before/equal to the bldcutoff */
  eedatev=min(eedatev,"&bldctoff"d);

  /* generate observations for each time unit in the time span */
  nunits=intck("&hedunit",edatev,eedatev);
  if nunits ge 0 then do i=0 to nunits;
    action_dt=intnx("&hedunit",edatev,i,"&hedstart");
    output hdhist;
  end;
  drop i nunits VALID_TO_DT action_type_cd;
  format action_dt &datefrmt;
run;


/* make sure they are sorted in ascending order and remove any duplicated dates */
proc sort data=hdhist out=hdhist;
  by &basekeys;
run;

data hdhist;
  set hdhist;
  by &basekeys;
  if last.action_dt;
run;


/* build the initial keys data set */
%joinkeys(basetabl=hdhist,basekeys=&basekeys,joinkeys=&joinkeys,init=Y);


/* join in position information */
%hrjoin(table=hdhist1,base=keys,basejvar=position_cd,
        join=hcmdata.pos,joinjvar=position_cd,
        basekey=&basekeys,basedate=action_dt,joindate=VALID_FROM_DT,
        dropvars=&posm job_cd employee_id ,eedtevar=VALID_TO_DT);


/* see if we need to pick up additional keys from pos */
%joinkeys(basetabl=hdhist1,basekeys=&basekeys,joinkeys=&joinkeys);


/* join in job information */
%hrjoin(table=hdhist2,base=keys,basejvar=job_cd,
        join=hcmdata.jobs,joinjvar=job_cd,
        basekey=&basekeys,basedate=action_dt,joindate=VALID_FROM_DT,
        dropvars=&jobsm ,eedtevar=VALID_TO_DT);

/* see if we need to pick up additional keys from jobs */
%joinkeys(basetabl=hdhist2,basekeys=&basekeys,joinkeys=&joinkeys);


/* join in hierarchy information */
data keyshr(drop=pay_level_structure_cd position_cd job_cd);
      set keys;run;
%grphiers(baseds=keyshr,grplevds=hcmdata.wrkgrp,basedate=VALID_FROM_DT,eedtevar=VALID_TO_DT,
         hiername=hiermax,rptgrp=intorg,prntgrp=parent_intorg,mgrname=MANAGER_NAME,
         outds=rptgrphr,joindate=VALID_FROM_DT);
data hdhist3;
 set rptgrphr(drop=grpdesc);
run;

/* join in pay grade information */
%hrjoin(table=hdhist4,base=keys,basejvar=pay_level_structure_cd,
        join=hcmdata.grade,joinjvar=pay_level_structure_cd,
        basekey=&basekeys,basedate=action_dt,joindate=VALID_FROM_DT,
        dropvars=&gradem ,eedtevar=VALID_TO_DT);


/* see if we need to pick up additional keys from grade */
%joinkeys(basetabl=hdhist4,basekeys=&basekeys,joinkeys=&joinkeys);


/* join in employee general information */
%cempgen;


%hrjoin(table=hdhist5,base=keys,basejvar=employee_id,
        join=cempgen,joinjvar=employee_id,
        basekey=&basekeys,dropvars=&empgenm VALID_FROM_DT VALID_TO_DT,eedtevar=VALID_TO_DT);

/* join all the lookup table information back to the original acthist data */
data hdsum;
  merge
        hdhist5
        hdhist4
        hdhist3
        hdhist2
        hdhist1
        hdhist(in=s)
  ;
  by &basekeys;
  if s;
  keep &keepvars fte_rt HEADCNT action_dt;

  /* use only active employees */
  if put(employee_status_cd,$iempsta.) ne "IN";

  /* recalculate age as of effective date */
  %AGE

   /* create a HEADCNT variable so there is something to count in PROC SUMMARY */
  retain fte_rt HEADCNT 1;

  /* drop any additional variables */
  %DROPVAR(dropvar=headsumv);

run;

%deltable(tables=hdhist hdhist1 hdhist2 hdhist3 hdhist4 hdhist5 rptgrphr keyshr);

/* collapse the headsum data set to one obs per dimension per time unit */
proc summary nway missing data=hdsum;
  class &keepvars action_dt;
  output out=hdsum(drop=_type_ _freq_) sum=HEADCNT FTECNT;
  var HEADCNT FTE_RT;
run;


/**********************************************************************/
/* this section builds a file of job actions to be counted and then   */
/* merged back with the headcount data                                */
/**********************************************************************/

/* get action records from acthmast */
data actions;
  set hcmdata.acthmast(where=(int(action_dt) gt &prevdate and
                              int(action_dt) le "&bldctoff"d));
  keep &keepvars faction action_dt action_type_cd ;


/* if _n_=1200 then stop;*/

  /* take care of the problem that the dates might not be integers */
  if action_dt ne . then action_dt=int(action_dt);

  /* get the anniversay just after edate */
  edatev=intnx("&hedunit",action_dt,0,"&hedstart");
  if edatev lt action_dt then edatev=intnx("&hedunit",action_dt,1,"&hedstart");
  drop edatev;

  if edatev gt "&bldctoff"d then edatev="&bldctoff"d;

  /* reset edate to the newly calculated anniversary date */
  action_dt=edatev;

/* count actions as of the beginning or end of a time period interval */
  if upcase(symget("hedcalc"))='B' then
  action_dt=intnx("&hedunit",action_dt,-1,"&hedstart");

  /* macro call to define action code categories */
  length faction $10;
  %actcodes;

run;

/* collapse the actions data set to one obs per dimension per time unit */
proc summary nway missing data=actions;
  class &keepvars action_dt faction;
  output out=actsum(drop=_type_ rename=(_freq_=count));
run;

proc transpose data=actsum
  out=actt(drop=_NAME_);
  by &keepvars action_dt;
  var count;
  id faction;
run;

/* merge the headcount with the action counts */
data hdsum;
  merge hdsum actt;
  by &keepvars action_dt;
run;

%deltable(tables=actsum actt actions);

/************************************************************************************/
/*              end of actions summary section                                      */
/************************************************************************************/

/* identify the variables that contain action counts                   */
/* the number of and name of these variables is unknown                */
/* the value in these variables needs to be carried into new records   */
/* that will be generated to fill in date gaps                         */
%macro vars;
%global elements;
%local start stop;
%let elements=;
data _null_;
  dsid=open("HDSUM");
  if dsid gt 0 then do;
    edatevn=varnum(dsid,'ACTION_DT');
    nvars=attrn(dsid,'NVARS');
    do i=edatevn+1 to nvars;
      varname=varname(dsid,i);
      call symput('VAR'!!left(put(i,3.)) , varname);
    end;
    call symput('START',put(edatevn+1,3.));
    call symput('STOP',put(nvars,3.));
    dsid=close(dsid);
  end;
run;
%do i=&start %to &stop;
  %let elements=&elements &&var&i;
%end;
%mend;
%vars;

/* Generate records for any gaps in anniversary dates. */
/* This includes records back to the anniversary before the HDCUTOFF date, */
/* up to the BLDCTOFF date and any records missing inbetween */


data HEADSUM;
  set hdsum;
  by &keepvars;
  retain &hedmets .;
  retain lstedate;
  array elements &elements;
  array temps temp1-temp30;
  drop temp1-temp30;

  /* set the expected anniversary date for this record.   */
  /* &prevdate is the anniversary before the cutoff date */
  /* lstedate is the edate of the last record output */
  if first.&lastvar then exptdate="&hdcutoff"d;
  else exptdate=intnx("&hedunit",lstedate,1,"&hedstart");

  /* generate records back to the anniversary before the cutoff */
  /* or to fill in date gaps if necessary.                       */
  if (action_dt gt exptdate) then do;
    nunits=intck("&hedunit",exptdate,action_dt);
    if action_dt="&bldctoff"d then nunits=nunits+1;
    format o_edate date9.;
    if nunits gt 0 then do i=0 to nunits-1;
      link save;
      action_dt=intnx("&hedunit",exptdate,i,"&hedstart");
      if action_dt lt exptdate then output;
      link reload;
    end;
  end;

  /* generate records up to and including the BLDCTOFF date if necessary */
  if last.&lastvar then do;
    exptdate="&bldctoff"d;
    if action_dt lt exptdate  then do;
      nunits=intck("&hedunit",exptdate,action_dt);
      o_edate=action_dt;
      do i=0 to nunits+1 by -1;
        link save;
        action_dt=intnx("&hedunit",exptdate,i,"&hedstart");
        if action_dt lt exptdate then output;
        link reload;
      end;
      link save;
      action_dt=exptdate;
      output;
      link reload;
    end;
  end;

  output;
  lstedate=action_dt;
  drop exptdate lstedate o_edate nunits i;
return;

/* the current records count values are about to be overwritten */
/* save the values until the record is written out              */
save:
  do over elements;
    temps=elements;
  end;
  o_edate=action_dt;
  do over elements;
     elements=.;
  end;
return;

/* the current record is about to be written out */
/* reload it with its count values            */
reload:
  do over elements;
    elements=temps;
  end;
 action_dt=o_edate;
return;


run;

/* set _lastrec and place into final location */
proc sort data=headsum;by employee_id action_dt;
data hcmdata.HEADSUM(rename=(action_dt=VALID_DT));
 set headsum;by employee_id action_dt;
 If last.employee_id then _lastrec='Y';
                     else _lastrec='N';
 %YRQTRMON(date=ACTION_DT,year=YEAR,qtr=QTR,month=MONTH);
run;

%deltable(tables=hdsum headsum);

/* restore the original value of the fmterr option */
options &fmterr;

%regrdata(sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
          sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
          sesetl_sasLibrary=hcmdata,sesetl_physicalTable=HEADSUM);

%mend;
