%macro opossum;

options &mprint &source &notes;

%let table=hcmdata.openpos;

options metarepository="&HRRepos";
%LibConOp(sesetl_sasLibRef=HCMDATA,
         sesetl_ChkDepRepos=Y
         ) ;
proc sql;
    connect to &sesetl_EngineType as PASSTHRU
               (&sesetl_BestLogin &sesetl_ConnectionOptions );
       execute(drop table if exists opossum
               ) by PASSTHRU;
    disconnect from PASSTHRU;
QUIT;


/* TGL  3/24/99  - RPTGRP needs to be in OPOSSUM, so there's at least one key */

%let keepvars=%classgen(prefix=&default_hier) internal_org_id &opsvars &opmcubev &opmanal;
%let lastvar=%reverse(%scan(%reverse(&keepvars),1));
%let basekeys=position_cd open_dt;
%let joinkeys=position_cd job_cd internal_org_id;

%deltable(tables=opossum opossum2 yearsum ophist poshist1 poshist2 poshist3);

%let prevdate=;
/* get the anniversary before before the cutoff.  Use this as the beginning */
/* so the change statistics can be calculated beginning with the cutoff date.*/
data _null_;
  prevdate=intnx("&opsunit","&opcutoff"d,-1,"&opsstart");
  call symput('prevdate',put(prevdate,6.));
run;


/* get the appropriate oposhist records, calculate cutoff anniversary dates */
data ophist;
  set &table(where=(open_dt ne . and open_dt le "&bldctoff"d));


*if _n_=100 then stop;

  /* take care of the problem that the dates might not be integers */
  open_dt=int(open_dt);
  if close_dt ne . then close_dt=int(close_dt);

  /* create a working close_dt */
  if close_dt=. then w_closdt="&bldctoff"d;
  else w_closdt=close_dt;
  drop w_closdt;

  /* get the anniversay just before close_dt */
  closdtev=intnx("&opsunit",w_closdt,0,"&opsstart");
  if closdtev gt w_closdt then closdtev=intnx("&opsunit",w_closdt,-1,"&opsstart");
  drop closdtev;

  /* get the anniversay just after open_dt */
  opendtev=intnx("&opsunit",open_dt,0,"&opsstart");
  if opendtev lt open_dt then opendtev=intnx("&opsunit",open_dt,1,"&opsstart");
  drop opendtev;

  /* keep only records that are not on the same time unit */
  if closdtev ge opendtev;

  /* keep only records valid after the cutoff and before the build date */
  if closdtev ge &prevdate and opendtev le "&bldctoff"d;

  /* reset opendtev to the next anniversary after/equal to the cutoff */
  opendtev=max(opendtev,&prevdate);

  /* reset closdtev to the anniversary before/equal to the bldcutoff date */
  closdtev=min(closdtev,"&bldctoff"d);

  /* generate observations for each time unit in the time span */
  nunits=intck("&opsunit",opendtev,closdtev);
  if nunits ge 0 then do i=0 to nunits;
    open_dt=intnx("&opsunit",opendtev,i,"&opsstart");
    output;
  end;
  drop i nunits close_dt;
  format open_dt &datefmt;
run;


/* make sure it is sorted in ascending order and remove any duplicated dates */
proc sort data=ophist out=ophist;
  by &basekeys;
run;

data ophist;
  set ophist;
  by &basekeys;
  if last.open_dt;
run;


/* build the initial keys data set */
%joinkeys(basetabl=ophist,basekeys=&basekeys,joinkeys=&joinkeys,init=Y);

/* join in position information */
%hrjoin(table=poshist1,base=keys,basejvar=position_cd,
        join=hcmdata.pos,joinjvar=position_cd,
        basekey=&basekeys,basedate=open_dt,joindate=valid_from_dt,dropvars=&posm,eedtevar=valid_to_dt);


/* see if we need to pick up additional keys from pos */
%joinkeys(basetabl=poshist1,basekeys=&basekeys,joinkeys=&joinkeys);

/* join in job information */
%hrjoin(table=poshist2,base=keys,basejvar=job_cd,
        join=hcmdata.jobs,joinjvar=job_cd,
        basekey=&basekeys,basedate=open_dt,joindate=valid_from_dt,dropvars=&jobsm,eedtevar=valid_to_dt);


/* see if we need to pick up additional keys from jobs */
%joinkeys(basetabl=poshist2,basekeys=&basekeys,joinkeys=&joinkeys);


/* join in hierarchy information */
data keyshr(rename=(internal_org_id=intorg));
      set keys;run;
%grplevs(baseds=keyshr,grplevds=hcmdata.wrkgrp,basedate=open_dt,eedtevar=valid_to_dt,
         hiername=hiermax,rptgrp=intorg,prntgrp=parent_intorg,
         outds=rptgrphr,joindate=VALID_FROM_DT,root=&default_hier,mgrname=MANAGER_NAME);
data poshist3;set rptgrphr(rename=(intorg=internal_org_id)drop= grpdesc);run;

/* join all the lookup table information back to the original acthist data */
data opossum;
  merge
        poshist3
        poshist2
        poshist1
        ophist(in=s)
  ;
  by &basekeys;
  if s;
  keep &keepvars open_dt ;
run;


/* collapse the opossum data set to one obs per year/month dimension */
proc summary nway missing data=opossum;
  class &keepvars open_dt;
  output out=opossum2(drop=_type_ rename=(_freq_=oposcnt));
run;

/* summarize a separate data set that has company totals for the year/month */
proc summary nway data=opossum2;
  class open_dt;
  output out=yearsum(compress=no drop=_type_ _freq_ rename=(open_dt=start)) sum=totcnt;
  var oposcnt;
run;


/* build a format out of the OPOSSUM data set so the totals can be looked up */
/* this is in lieu of sorting the OPOSSUM data set twice to do a merge      */
data yearsum(compress=no);
  set yearsum;
  fmtname='totcnt';
  label=put(totcnt,8.);
run;
proc sort data=yearsum;
  by fmtname start;
run;
proc format cntlin=yearsum;
run;

%let maxdate=;
/* get the last yearmon of analysis */
/*YEARSUM must be build without compression for this to work */
data _null_;
  set yearsum point=nobs nobs=nobs;
  call symput('maxdate',put(start,6.));
  stop;
run;


/* calculate changes in oposcnt from/to each year/month */

/* we need to check to see if there are gaps in the time sequence */
/* sequence for a given by group */
%global opossumindx;
data hcmdata.OPOSSUM(%idxcreat(&opossumindx)rename=(edate=VALID_DT));
  set opossum2(rename=(open_dt=edate));
  by &keepvars;

  /* if this is the first for the group, preset the change */
  /* count to what the count is for this time unit */
  if first.&lastvar then do;
    /* get the company totals so you can calculate a percentage */
    totcnt=input(put(edate,totcnt.),8.);
    if totcnt not in (0,.) then cntpct=oposcnt/totcnt;
    /* reset the change statistics */
    opdif=oposcnt;
    opchgpct=.;
    link output;
  end;

  /* handle the case where there is a time unit gap */
  else if intnx("&opsunit",edate,-1,"&opsstart") ne prevdate then do;
    /* save the current information */
    oldedate=edate;
    oldopcnt=oposcnt;

    /* get the totals based on the current date, then adjust */
    totcnt=input(put(edate,totcnt.),8.);
    if totcnt ne . then totcnt=totcnt-oposcnt;
    if totcnt not in (0,.) then cntpct=oposcnt/totcnt;

    /* set a unit one past the last valid time unit */
    edate=intnx("&opsunit",prevdate,1,"&opsstart");

    /* set the statistics to negate the last output record */
    oposcnt=0;
    opdif=-lastcnt;
    opchgpct=-1;
    link output;

    /* reset the date and stats back to the current record */
    edate=oldedate;
    oposcnt=oldopcnt;

    /* recalculate the change stats for the original data */
    opdif=oposcnt;
    opchgpct=.;

    /* reset the totals based on the original date */
    totcnt=input(put(edate,totcnt.),8.);
    if totcnt not in (0,.) then cntpct=oposcnt/totcnt;

    /* put out the original record */
    link output;
  end;

  /* handle the normal situation */
  else do;
    /* calculate the change stats for the current data */
    if lastcnt ne . then do;
      opdif=oposcnt-lastcnt;
      if lastcnt ne 0 then opchgpct=opdif/lastcnt;
    end;
    totcnt=input(put(edate,totcnt.),8.);
    if totcnt not in (0,.) then cntpct=oposcnt/totcnt;
    link output;
  end;

  /* put out a record if the last record isn't for the last possible time unit */
  if last.&lastvar and edate ne &maxdate then do;
    totcnt=input(put(edate,totcnt.),8.);
    edate=intnx("&opsunit",edate,1,"&opsstart");
    if totcnt ne . then totcnt=totcnt-oposcnt;
    if totcnt not in (0,.) then cntpct=oposcnt/totcnt;
    opdif=-oposcnt;
    oposcnt=.;
    opchgpct=-1;
    link output;
  end;
return;

output:
  retain prevdate;
  prevdate=edate;
  if edate ge "&opcutoff"d then output;
  /* keep the counts for change calculations */
  lastcnt=oposcnt;
  retain lastcnt;
return;

  format cntpct opchgpct percent8.2 opdif totcnt
         oposcnt comma10. edate &datefmt.;
  drop prevdate oldedate oldopcnt lastcnt;

  /* drop any additional variables */
  %DROPVAR(dropvar=opssumv);
run;


/* clean up */
%deltable(tables=opossum opossum2 yearsum ophist poshist1 poshist2 poshist3);

%regrdata(sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
          sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
          sesetl_sasLibrary=hcmdata,sesetl_physicalTable=OPOSSUM);

%mend;
