%macro wrkgrp;

options &mprint &source &notes;

options metarepository="&HRRepos";
%LibConOp(sesetl_sasLibRef=HCMDATA,
         sesetl_ChkDepRepos=Y
         ) ;
proc sql;
    connect to &sesetl_EngineType as PASSTHRU
               (&sesetl_BestLogin &sesetl_ConnectionOptions );
       execute(drop table if exists wrkgrp
               ) by PASSTHRU;
    disconnect from PASSTHRU;
QUIT;

/* make sure work library has no current copies of the needed work datasets */
%deltable(tables=wrkgrp1 wrkgrp2 wrkgrp3 wrkgrp4 wrkgrp);
%let wrkhiers = ;
%do i=1 %to &number_of_hiers;
    %let hier=%scan(&hiers, &i);
        %if &i > 1 %then %do;
       %let wrkhiers = &wrkhiers, %quote(%'&hier%');
    %end;
    %else %do;
       %let wrkhiers = %quote(%'&hier%');
    %end;
%end;

/* get the child parent records for the HR_org */
data wrkgrp1(rename=(internal_org_assoc_type_cd=HIERARCHY_CD)drop=valid_from_dttm valid_to_dttm);
 set conform.internal_org_assoc(drop=processed_dttm order_no internal_org_adk);
 if internal_org_assoc_type_cd in (%unquote(&wrkhiers));
 VALID_FROM_DT=datepart(valid_from_dttm);
 VALID_TO_DT=datepart(valid_to_dttm);
 format VALID_FROM_DT VALID_TO_DT date9.;
proc sort;by internal_org_rk;
run;

/* get the int_org_id from the member table to join to the child/parent table */
data wrkgrp2;
 set conform.internal_org(keep=internal_org_rk internal_org_id managing_employee_rk);
  proc sort nodup;by internal_org_rk;
run;

/* join the child/parent table and the member table to add the int_org_id  */
/* rename columns so that we can join and get the parent_int_org_id        */
data wrkgrp3(drop=internal_org_rk rename=(internal_org_id=child_int_org_id
                                          parent_internal_org_rk=internal_org_rk));
 merge wrkgrp1(in=a) wrkgrp2;by internal_org_rk;if a;
 proc sort;by internal_org_rk;
run;

/* join to the member table again to get the ID for the parent_internal_org_rk */
/* Remove the sort once we have dates */
data wrkgrp4(drop=internal_org_rk child_int_org_id internal_org_id);
 merge wrkgrp3(in=a) wrkgrp2(drop=managing_employee_rk);by internal_org_rk;if a;
 INTORG=child_int_org_id;
 PARENT_INTORG=internal_org_id;
 label PARENT_INTORG=' '
       INTORG=' ';
 proc sort;by INTORG;
run;

/* get the description for the INTORG */
data org_desc;
 set conform.internal_org(keep=internal_org_id organization_desc
                          rename=(internal_org_id=INTORG organization_desc=GRPDESC));
 label GRPDESC=' ';
 label INTORG=' ';
proc sort nodup;by INTORG;
run;

data wrkgrp;
 merge wrkgrp4(in=a) org_desc;
   by INTORG;if a;
   proc sort;by managing_employee_rk;
run;

/* Get the Employee Names to join with the Managing_Employee_RK */
data employee(keep=managing_employee_rk MANAGER_NAME MANAGER_ID);
 set conform.employee(keep=Employee_RK first_nm last_nm employee_id
                      rename=(Employee_RK=managing_employee_rk
                              employee_id=MANAGER_ID));
if FIRST_NM ne ' '  then
 MANAGER_NAME=trim(LAST_NM) || ',' || trim(FIRST_NM);else
 MANAGER_NAME=LAST_NM;
proc sort nodupkey;by managing_employee_rk;
run;

/* Exclude orgmember_excludes variables from the merged dataset*/
data wrkgrp(drop=managing_employee_rk);
 merge wrkgrp(in=a) employee;by managing_employee_rk;if a;
 if index("&orgmember_excludes", trim(intorg)) = 0;
 if index("&orgmember_excludes", trim(parent_intorg)) then
    parent_intorg ="";
run;

/* set _lastrec and place into final sorted order and location */
proc sort data=wrkgrp;by hierarchy_cd intorg descending valid_from_dt;
data wrkgrp;
 set wrkgrp;by hierarchy_cd intorg descending valid_from_dt;
 If first.intorg then _lastrec='Y';
 else _lastrec='N';
 proc sort data=wrkgrp out=hcmdata.wrkgrp;
 by &wrksort;
run;


%let dwdset=hcmdata.wrkgrp;
%wrkgrp2(rptgrp=intorg,prntgrp=parent_intorg,grplevds=hcmdata.wrkgrp,wrksort=intorg,
        edate=valid_from_dt,eedate=valid_to_dt,hiername=hiermax);

/* clean up */
%deltable(tables=wrkgrp1 wrkgrp2 wrkgrp3 wrkgrp4 wrkgrp org_desc);
%regrdata(sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
          sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
          sesetl_sasLibrary=hcmdata,sesetl_physicalTable=wrkgrp);
%mend;
