%macro newdim(NEW_DIMENSION=&dimname);
%let stopflag=0;
%if &new_dimension^=%str() %then %do  ;
  %let l=%sysfunc(length(&new_dimension));
  %if &l>16 %then %do;
     %put  ERROR:  The Dimension name cannot exceed 16 characters in length.;
     %let stopflag=1;
  %end;

  %let _wrong=%sysfunc( compress( %sysfunc( substr(&new_dimension, 1, 1)), , f));
  %let _wrongrest=%sysfunc( compress( %sysfunc( substr(&new_dimension, 2)), , n));

  %if &_wrong^=%str() or &_wrongrest^=%str() %then %do;
     %put  ERROR:  The Dimension name is not a valid sasname "&new_dimension".;
     %let stopflag=1;
  %end;
%end;
%else %do;
     %put  ERROR:  The option Dimension Name has not been defined in the options tab.;
     %let stopflag=1;
%end;
%if &stopflag=1 %then %return;

options metarepository="&ddsrepos";
%let _stageDDSLib=STAGEDDS;
%let _DDSLib=DDS;

%bldLibNm(sesetl_sasLibref=&_stageDDSLib,
          sesetl_ChkDepRepos=Y,
          sesetl_useMLE=N
         ) ;

%bldLibNm(sesetl_sasLibRef=&_DDSLib,
          sesetl_ChkDepRepos=Y,
          sesetl_useMLE=N
         ) ;

/* ddl for stage */
%LET  NEW_DIMENSION=%upcase(%TRIM(&NEW_DIMENSION));
%put &new_dimension;

%LET LIBREF=&_stageDDSLib;
%let DTTMFMT=DATETIME21.;
%let DTFMT= DATE9.;

PROC SQL;

  CREATE TABLE &LIBREF..&NEW_DIMENSION (
    &NEW_DIMENSION._ID     VARCHAR(32) label="&NEW_DIMENSION ID",
    VALID_FROM_DTTM        DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid From Date',
    VALID_TO_DTTM          DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid To Date',
    SOURCE_SYSTEM_CD       VARCHAR(3) label='Source System Code',
    &NEW_DIMENSION._NM     VARCHAR(50) label="&NEW_DIMENSION Name",
    &NEW_DIMENSION._DESC   VARCHAR(255) label="&NEW_DIMENSION Description",
    &NEW_DIMENSION._ADK    VARCHAR(32)
  );
  CREATE INDEX TBL_INDX ON &LIBREF..&NEW_DIMENSION (&NEW_DIMENSION._ID, VALID_FROM_DTTM);

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC (
    &NEW_DIMENSION._ID            VARCHAR(32) label="&NEW_DIMENSION ID",
    PARENT_&NEW_DIMENSION._ID     VARCHAR(32) label="Parent &NEW_DIMENSION ID",
    &NEW_DIMENSION._ASSOC_TYPE_CD VARCHAR(32) label="&NEW_DIMENSION Association Type Code",
    VALID_FROM_DTTM               DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid From Date',
    VALID_TO_DTTM                 DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid To Date',
    ORDER_NO                      NUMERIC(8) label='Order Number',
    &NEW_DIMENSION._ADK           VARCHAR(32)
  );
  CREATE INDEX TBL_INDX ON &LIBREF..&NEW_DIMENSION._ASSOC (&NEW_DIMENSION._ID, PARENT_&NEW_DIMENSION._ID, &NEW_DIMENSION._ASSOC_TYPE_CD, VALID_FROM_DTTM);

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC_TYPE (
    &NEW_DIMENSION._ASSOC_TYPE_CD    VARCHAR(32) label="&NEW_DIMENSION Association Type Code",
    VALID_FROM_DTTM                  DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid From Date',
    LANGUAGE_CD                      VARCHAR(3) label='Language Code',
    VALID_TO_DTTM                    DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid To Date',
    &NEW_DIMENSION._ASSOC_TYPE_DESC  VARCHAR(255) label="&NEW_DIMENSION Association Type Code",
    &NEW_DIMENSION._ADK              VARCHAR(32),
    DEFAULT_&NEW_DIMENSION._ID       VARCHAR(32)
  );
  CREATE INDEX TBL_INDX ON &LIBREF..&NEW_DIMENSION._ASSOC_TYPE (&NEW_DIMENSION._ASSOC_TYPE_CD, LANGUAGE_CD, VALID_FROM_DTTM);

QUIT;

/* ddl for dds */
%LET LIBREF=&_DDSLib;

PROC SQL;

  CREATE TABLE &LIBREF..&NEW_DIMENSION (
    &NEW_DIMENSION._RK   NUMERIC(10) label="&NEW_DIMENSION Retained Key",
    VALID_FROM_DTTM      DATE NOT NULL FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid From Date',
    PROCESSED_DTTM       DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Date/Time Processed by ETL',
    VALID_TO_DTTM        DATE NOT NULL FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid To Date',
    &NEW_DIMENSION._ID   VARCHAR(32) label="&NEW_DIMENSION ID",
    SOURCE_SYSTEM_CD     VARCHAR(3) label='Source System Code',
    &NEW_DIMENSION._NM   VARCHAR(50) label="&NEW_DIMENSION Name",
    &NEW_DIMENSION._DESC VARCHAR(255) label="&NEW_DIMENSION Description",
    &NEW_DIMENSION._ADK  VARCHAR(32),
    CONSTRAINT PRIM_KEY PRIMARY KEY (&NEW_DIMENSION._RK, VALID_FROM_DTTM)
  );

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC (
    &NEW_DIMENSION._RK            NUMERIC(10) label="&NEW_DIMENSION Retained Key",
    PARENT_&NEW_DIMENSION._RK     NUMERIC(10) label="Parent &NEW_DIMENSION Retained Key",
    &NEW_DIMENSION._ASSOC_TYPE_CD VARCHAR(32) label="&NEW_DIMENSION Association Type Code",
    VALID_FROM_DTTM               DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid From Date',
    VALID_TO_DTTM                 DATE NOT NULL FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid To Date',
    PROCESSED_DTTM                DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Date/Time Processed by ETL',
    ORDER_NO                      NUMERIC(8) label='Order Number',
    &NEW_DIMENSION._ADK           VARCHAR(32),
    CONSTRAINT PRIM_KEY PRIMARY KEY (&NEW_DIMENSION._RK, PARENT_&NEW_DIMENSION._RK, &NEW_DIMENSION._ASSOC_TYPE_CD, VALID_FROM_DTTM)
  );

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC_TYPE (
    &NEW_DIMENSION._ASSOC_TYPE_CD   VARCHAR(32) label="&NEW_DIMENSION Association Type Code",
    VALID_FROM_DTTM                 DATE NOT NULL FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid From Date',
    LANGUAGE_CD                     VARCHAR(3) label='Language Code',
    VALID_TO_DTTM                   DATE NOT NULL FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid To Date',
    &NEW_DIMENSION._ASSOC_TYPE_DESC VARCHAR(255) label="&NEW_DIMENSION Association Type Code",
    PROCESSED_DTTM                  DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Date/Time Processed by ETL',
    &NEW_DIMENSION._ADK             VARCHAR(32),
    DEFAULT_&NEW_DIMENSION._RK      NUMERIC(10),
    CONSTRAINT PRIM_KEY PRIMARY KEY (&NEW_DIMENSION._ASSOC_TYPE_CD,LANGUAGE_CD, VALID_FROM_DTTM)
  );

QUIT;

/* ddl for scd */
%LET LIBREF=&_DDSLib;

PROC SQL;

  CREATE TABLE &LIBREF..&NEW_DIMENSION._X (
    &NEW_DIMENSION._RK  NUMERIC(10),
    &NEW_DIMENSION._ID  VARCHAR(32),
    VALID_FROM_DTTM     DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT,
    DIGEST_VALUE        VARCHAR(32)
  );

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC_X (
    &NEW_DIMENSION._RK            NUMERIC(10),
    PARENT_&NEW_DIMENSION._RK     NUMERIC(10),
    &NEW_DIMENSION._ASSOC_TYPE_CD VARCHAR(32),
    VALID_FROM_DTTM               DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT,
    DIGEST_VALUE                  VARCHAR(32)
  );

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC_TYPE_X (
    &NEW_DIMENSION._ASSOC_TYPE_CD VARCHAR(32),
    VALID_FROM_DTTM               DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT,
    DIGEST_VALUE                  VARCHAR(32),
    LANGUAGE_CD                   VARCHAR(3)
  );

QUIT;

%let iomserver=&sesetl_serverContext;
%let libname=&_DDSLib;

/* REGISTER NEW_DIMENSION DDS Tables */
%regMdata(sesetl_serverContext=&iomserver,
  sesetl_sasLibrary=&libname,
  sesetl_physicalTable=&NEW_DIMENSION,
  sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
  sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
  sesetl_ddsTree=D,
  sesetl_ddsVersion=DDS SAS Supplied Model - v1.2,
  sesetl_OMRTableObjName=&NEW_DIMENSION
  );

%regMdata(sesetl_serverContext=&iomserver,
  sesetl_sasLibrary=&libname,
  sesetl_physicalTable=&NEW_DIMENSION._ASSOC,
  sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
  sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
  sesetl_ddsTree=D,
  sesetl_ddsVersion=DDS SAS Supplied Model - v1.2,
  sesetl_OMRTableObjName=&NEW_DIMENSION._ASSOC
  );

%regMdata(sesetl_serverContext=&iomserver,
  sesetl_sasLibrary=&libname,
  sesetl_physicalTable=&NEW_DIMENSION._ASSOC_TYPE,
  sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
  sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
  sesetl_ddsTree=D,
  sesetl_ddsVersion=DDS SAS Supplied Model - v1.2,
  sesetl_OMRTableObjName=&NEW_DIMENSION._ASSOC_TYPE
  );


/* REGISTER NEW_DIMENSION StageDDS Tables */
%let iomserver=&sesetl_serverContext;
%let libname=&_stageDDSLib;

%regMdata(sesetl_serverContext=&iomserver,
  sesetl_sasLibrary=&libname,
  sesetl_physicalTable=&NEW_DIMENSION,
  sesetl_ddsTreeName=Staging Tables,
  sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
  sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
  sesetl_ddsTree=D,
  sesetl_ddsVersion=DDS SAS Supplied Model - v1.2,
  sesetl_OMRTableObjName=STAGE_&NEW_DIMENSION
  );

%regMdata(sesetl_serverContext=&iomserver,
  sesetl_sasLibrary=&libname,
  sesetl_physicalTable=&NEW_DIMENSION._ASSOC,
  sesetl_ddsTreeName=Staging Tables,
  sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
  sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
  sesetl_ddsTree=D,
  sesetl_ddsVersion=DDS SAS Supplied Model - v1.2,
  sesetl_OMRTableObjName=STAGE_&NEW_DIMENSION._ASSOC
  );

%regMdata(sesetl_serverContext=&iomserver,
  sesetl_sasLibrary=&libname,
  sesetl_physicalTable=&NEW_DIMENSION._ASSOC_TYPE,
  sesetl_ddsTreeName=Staging Tables,
  sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree,
  sesetl_altEtlStudioGroupNm=Data Integration Studio Groups,
  sesetl_ddsTree=D,
  sesetl_ddsVersion=DDS SAS Supplied Model - v1.2,
  sesetl_OMRTableObjName=STAGE_&NEW_DIMENSION._ASSOC_TYPE
  );

%mend;
