%macro newdtype(
       NEW_DIMENSION=&dimtype
     , DIM_TYPE_CD=&dimtype
     , LANGUAGE_CD=&languageCd
     , TABLE_NM=&dimtype
     , DIM_TYPE_NM=&dimtype Dimension Type
     , DIM_TYPE_DESC=&dimtype Dimension Type
     , BASE_FACT_COLUMN_NM=&dimtype._RK
     , BUSINESS_ID_COLUMN_NM=&dimtype._ID
     , ASSOC_TABLE_NM=&dimtype._ASSOC
     , ASSOC_TYPE_TABLE_NM=&dimtype._ASSOC_TYPE
     , KEY_COLUMN_NM=&dimtype._RK
     , SOURCE_LIBREF=&sourceLibref
     , SOURCE_TREE=&sourceTree
     , ADD_TO_FACT_TABLE=&addToFactTable
     );

%let stopflag=0;

%let iomserver=&sesetl_serverContext;

%if    &DIM_TYPE_CD eq %str() or &LANGUAGE_CD eq %str()
    or &TABLE_NM eq %str() or &DIM_TYPE_NM eq %str() or &DIM_TYPE_DESC eq %str()
    or &BASE_FACT_COLUMN_NM eq %str() or &BUSINESS_ID_COLUMN_NM eq %str()
    or &ASSOC_TABLE_NM eq %str() or &ASSOC_TYPE_TABLE_NM eq %str()
    or &KEY_COLUMN_NM eq %str() or &SOURCE_LIBREF eq %str()
    or &SOURCE_TREE eq %str() or &ADD_TO_FACT_TABLE eq %str()
       %then %do;
  %put  ERROR:  One or more parameters have no value defined.;
  %let stopflag=1;
%end;
%if &stopflag=1 %then %return;

%let l=%sysfunc(length(&new_dimension));
%if &l>16 %then %do;
   %put  ERROR:  The Dimension Type Name cannot exceed 16 characters in length.;
   %let stopflag=1;
%end;
%if &stopflag=1 %then %return;

%let _wrong=%sysfunc( compress( %sysfunc( substr(&new_dimension, 1, 1)), , f));
%let _wrongrest=%sysfunc( compress( %sysfunc( substr(&new_dimension, 2)), , n));

%if &_wrong^=%str() or &_wrongrest^=%str() %then %do;
   %put  ERROR:  The Dimension Type Name is not a valid sasname "&new_dimension".;
   %let stopflag=1;
%end;
%if &stopflag=1 %then %return;

%let _wrong=%sysfunc( compress( %sysfunc( substr(&source_libref, 1, 1)), , f));
%let _wrongrest=%sysfunc( compress( %sysfunc( substr(&source_libref, 2)), , n));

%if &_wrong^=%str() or &_wrongrest^=%str() %then %do;
   %put  ERROR:  The Source Libref is not a valid sasname "&source_libref".;
   %let stopflag=1;
%end;
%if &stopflag=1 %then %return;

options metarepository="&ddsrepos";
%let _stageDDSLib=STAGEDDS;
%let _DDSLib=DDS;

%bldLibNm(sesetl_sasLibref=&source_Libref,
          sesetl_ChkDepRepos=Y,
          sesetl_useMLE=N
         ) ;

%bldLibNm(sesetl_sasLibref=&_stageDDSLib,
          sesetl_ChkDepRepos=Y,
          sesetl_useMLE=N
         ) ;

%bldLibNm(sesetl_sasLibRef=&_DDSLib,
          sesetl_ChkDepRepos=Y,
          sesetl_useMLE=N
         ) ;

/* ddl for stage */
%LET  NEW_DIMENSION=%upcase(%TRIM(&NEW_DIMENSION));
%put &new_dimension;

%LET LIBREF=&_stageDDSLib;
%let DTTMFMT=DATETIME21.;
%let DTFMT= DATE9.;
%let _DATE=%sysfunc( date() );

%if %sysfunc( exist(&sourceLibref..SOURCE_DIMENSION_TYPE) ) %then %do;
  %let _colFound = 0;
  proc sql noprint;
    select 1 into :_colFound
    from &sourceLibref..SOURCE_DIMENSION_TYPE
    where dimension_type_cd eq "&NEW_DIMENSION"
    ;
  quit;
  %if &_colFound ne 0 %then %do;
     %put  ERROR:  The dimension type "&new_dimension" is already existing.;
     %let stopflag=1;
  %end;
%end;
%else %do;
  /* Create physical table and register in metadata */
  PROC SQL;
    create table &sourceLibref..SOURCE_DIMENSION_TYPE like &LIBREF..DIMENSION_TYPE
    ;
    CREATE INDEX TBL_INDX ON &sourceLibref..SOURCE_DIMENSION_TYPE
         (DIMENSION_TYPE_CD, LANGUAGE_CD, VALID_FROM_DTTM);
  QUIT;
  %let stgprefix=;
  %let sesetl_sasLibrary = &sourceLibref ;
  %let sesetl_registerTables = work._registerTables ;
  %let sesetl_version = DDS SAS Supplied Model - v1.2 ;
  %let sesetl_treeName = &source_Tree;
  %let sesetl_validTreeTypes = D:Dimension Tables @ R:Reference Tables @ F:Fact Tables ;
  %let sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree;
  %let sesetl_altEtlStudioGroupNm=Data Integration Studio Groups;
  %let sesetl_security = Y ;

  data &sesetl_registerTables ;
    length sasTableName    $255 ;
    length omrObjTableName $255 ;
    length treeType        $10 ;

    sasTableName    = "SOURCE_DIMENSION_TYPE";
    omrObjTableName = strip("&stgprefix." || sasTableName) ;
    treeType        = "R" ;
    output ;

  run;
  proc display c=sashelp.regdata.RegisterSASDataSets.scl;
  run;

%end;
%if &stopflag=1 %then %return;

proc sql noprint;
   insert into &sourceLibref..SOURCE_DIMENSION_TYPE (
     LANGUAGE_CD , VALID_FROM_DTTM, VALID_TO_DTTM, DIMENSION_TYPE_CD,
     TABLE_NM, DIMENSION_TYPE_NM, DIMENSION_TYPE_DESC, BASE_FACT_COLUMN_NM,
     BUSINESS_ID_COLUMN_NM, ASSOC_TABLE_NM, ASSOC_TYPE_TABLE_NM, KEY_COLUMN_NM)
   values ("&LANGUAGE_CD", &_DATE, ., "&NEW_DIMENSION",
     "&TABLE_NM", "&DIM_TYPE_NM", "&DIM_TYPE_DESC", "&BASE_FACT_COLUMN_NM",
     "&BUSINESS_ID_COLUMN_NM", "&ASSOC_TABLE_NM", "&ASSOC_TYPE_TABLE_NM", "&KEY_COLUMN_NM")
   ;
quit;

PROC SQL;

  CREATE TABLE &LIBREF..&NEW_DIMENSION (
    &NEW_DIMENSION._ID     VARCHAR(32) label="&NEW_DIMENSION ID",
    VALID_FROM_DTTM        DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid From Date',
    VALID_TO_DTTM          DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid To Date',
    SOURCE_SYSTEM_CD       VARCHAR(3) label='Source System Code',
    &NEW_DIMENSION._NM     VARCHAR(50) label="&NEW_DIMENSION Name",
    &NEW_DIMENSION._DESC   VARCHAR(255) label="&NEW_DIMENSION Description",
    &NEW_DIMENSION._ADK    VARCHAR(32)
  );
  CREATE INDEX TBL_INDX ON &LIBREF..&NEW_DIMENSION (&NEW_DIMENSION._ID, VALID_FROM_DTTM);

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC (
    &NEW_DIMENSION._ID            VARCHAR(32) label="&NEW_DIMENSION ID",
    PARENT_&NEW_DIMENSION._ID     VARCHAR(32) label="Parent &NEW_DIMENSION ID",
    &NEW_DIMENSION._ASSOC_TYPE_CD VARCHAR(32) label="&NEW_DIMENSION Association Type Code",
    VALID_FROM_DTTM               DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid From Date',
    VALID_TO_DTTM                 DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid To Date',
    ORDER_NO                      NUMERIC(8) label='Order Number',
    &NEW_DIMENSION._ADK           VARCHAR(32)
  );
  CREATE INDEX TBL_INDX ON &LIBREF..&NEW_DIMENSION._ASSOC (&NEW_DIMENSION._ID, PARENT_&NEW_DIMENSION._ID, &NEW_DIMENSION._ASSOC_TYPE_CD, VALID_FROM_DTTM);

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC_TYPE (
    &NEW_DIMENSION._ASSOC_TYPE_CD    VARCHAR(32) label="&NEW_DIMENSION Association Type Code",
    VALID_FROM_DTTM                  DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid From Date',
    LANGUAGE_CD                      VARCHAR(3) label='Language Code',
    VALID_TO_DTTM                    DATE FORMAT=&DTFMT INFORMAT=&DTFMT label='Valid To Date',
    &NEW_DIMENSION._ASSOC_TYPE_DESC  VARCHAR(255) label="&NEW_DIMENSION Association Type Code",
    &NEW_DIMENSION._ADK              VARCHAR(32),
    DEFAULT_&NEW_DIMENSION._ID       VARCHAR(32)
  );
  CREATE INDEX TBL_INDX ON &LIBREF..&NEW_DIMENSION._ASSOC_TYPE (&NEW_DIMENSION._ASSOC_TYPE_CD, LANGUAGE_CD, VALID_FROM_DTTM);

QUIT;

%if "&ADD_TO_FACT_TABLE" eq "Yes" %then %do;

  PROC SQL;

    ALTER TABLE &LIBREF..GL_TRANSACTION_SUM
      ADD &NEW_DIMENSION._ID VARCHAR(32) label="&NEW_DIMENSION ID" FORMAT=$32.
    ;

    ALTER TABLE &LIBREF..GL_JRNL_DETAILS
      ADD &NEW_DIMENSION._ID VARCHAR(32) label="&NEW_DIMENSION ID" FORMAT=$32.
    ;

  QUIT;

%end;

/* ddl for dds */
%LET LIBREF=&_DDSLib;

PROC SQL;

  CREATE TABLE &LIBREF..&NEW_DIMENSION (
    &NEW_DIMENSION._RK   NUMERIC(10) label="&NEW_DIMENSION Retained Key",
    VALID_FROM_DTTM      DATE NOT NULL FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid From Date',
    PROCESSED_DTTM       DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Date/Time Processed by ETL',
    VALID_TO_DTTM        DATE NOT NULL FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid To Date',
    &NEW_DIMENSION._ID   VARCHAR(32) label="&NEW_DIMENSION ID",
    SOURCE_SYSTEM_CD     VARCHAR(3) label='Source System Code',
    &NEW_DIMENSION._NM   VARCHAR(50) label="&NEW_DIMENSION Name",
    &NEW_DIMENSION._DESC VARCHAR(255) label="&NEW_DIMENSION Description",
    &NEW_DIMENSION._ADK  VARCHAR(32),
    CONSTRAINT PRIM_KEY PRIMARY KEY (&NEW_DIMENSION._RK, VALID_FROM_DTTM)
  );

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC (
    &NEW_DIMENSION._RK            NUMERIC(10) label="&NEW_DIMENSION Retained Key",
    PARENT_&NEW_DIMENSION._RK     NUMERIC(10) label="Parent &NEW_DIMENSION Retained Key",
    &NEW_DIMENSION._ASSOC_TYPE_CD VARCHAR(32) label="&NEW_DIMENSION Association Type Code",
    VALID_FROM_DTTM               DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid From Date',
    VALID_TO_DTTM                 DATE NOT NULL FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid To Date',
    PROCESSED_DTTM                DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Date/Time Processed by ETL',
    ORDER_NO                      NUMERIC(8) label='Order Number',
    &NEW_DIMENSION._ADK           VARCHAR(32),
    CONSTRAINT PRIM_KEY PRIMARY KEY (&NEW_DIMENSION._RK, PARENT_&NEW_DIMENSION._RK, &NEW_DIMENSION._ASSOC_TYPE_CD, VALID_FROM_DTTM)
  );

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC_TYPE (
    &NEW_DIMENSION._ASSOC_TYPE_CD   VARCHAR(32) label="&NEW_DIMENSION Association Type Code",
    VALID_FROM_DTTM                 DATE NOT NULL FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid From Date',
    LANGUAGE_CD                     VARCHAR(3) label='Language Code',
    VALID_TO_DTTM                   DATE NOT NULL FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Valid To Date',
    &NEW_DIMENSION._ASSOC_TYPE_DESC VARCHAR(255) label="&NEW_DIMENSION Association Type Code",
    PROCESSED_DTTM                  DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT label='Date/Time Processed by ETL',
    &NEW_DIMENSION._ADK             VARCHAR(32),
    DEFAULT_&NEW_DIMENSION._RK      NUMERIC(10),
    CONSTRAINT PRIM_KEY PRIMARY KEY (&NEW_DIMENSION._ASSOC_TYPE_CD,LANGUAGE_CD, VALID_FROM_DTTM)
  );

QUIT;

%if "&ADD_TO_FACT_TABLE" eq "Yes" %then %do;

  PROC SQL;

    ALTER TABLE &LIBREF..GL_TRANSACTION_SUM
      ADD &NEW_DIMENSION._RK NUMERIC(10) label="&NEW_DIMENSION Retained Key" FORMAT=8.
    ;

    ALTER TABLE &LIBREF..GL_JRNL_DETAILS
      ADD &NEW_DIMENSION._RK NUMERIC(10) label="&NEW_DIMENSION Retained Key" FORMAT=8.
    ;

  QUIT;

%end;

/* ddl for scd */
%LET LIBREF=&_DDSLib;

PROC SQL;

  CREATE TABLE &LIBREF..&NEW_DIMENSION._X (
    &NEW_DIMENSION._RK  NUMERIC(10),
    &NEW_DIMENSION._ID  VARCHAR(32),
    VALID_FROM_DTTM     DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT,
    DIGEST_VALUE        VARCHAR(32)
  );

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC_X (
    &NEW_DIMENSION._RK            NUMERIC(10),
    PARENT_&NEW_DIMENSION._RK     NUMERIC(10),
    &NEW_DIMENSION._ASSOC_TYPE_CD VARCHAR(32),
    VALID_FROM_DTTM               DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT,
    DIGEST_VALUE                  VARCHAR(32)
  );

  CREATE TABLE &LIBREF..&NEW_DIMENSION._ASSOC_TYPE_X (
    &NEW_DIMENSION._ASSOC_TYPE_CD VARCHAR(32),
    VALID_FROM_DTTM               DATE FORMAT=&DTTMFMT INFORMAT=&DTTMFMT,
    DIGEST_VALUE                  VARCHAR(32),
    LANGUAGE_CD                   VARCHAR(3)
  );

QUIT;

/* REGISTER NEW_DIMENSION DDS Tables */
%let libname=&_DDSLib;

%let stgprefix=;
%let sesetl_sasLibrary = &libname ;
%let sesetl_registerTables = work._registerTables ;
%let sesetl_version = DDS SAS Supplied Model - v1.2 ;
%let sesetl_treeName = Detail Data Store (DDS);
%let sesetl_validTreeTypes = D:Dimension Tables @ R:Reference Tables @ F:Fact Tables ;
%let sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree ;
%let sesetl_altEtlStudioGroupNm=Data Integration Studio Groups;
%let sesetl_security = Y ;

data &sesetl_registerTables ;
  length sasTableName    $255 ;
  length omrObjTableName $255 ;
  length treeType        $10 ;

  sasTableName    = "&NEW_DIMENSION";
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "&NEW_DIMENSION._ASSOC";
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "&NEW_DIMENSION._ASSOC_TYPE";
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;
run;
proc display c=sashelp.regdata.RegisterSASDataSets.scl;
run;

%if "&ADD_TO_FACT_TABLE" eq "Yes" %then %do;

  proc metalib;
    omr (library="&libname");
    update_rule (noadd);
    select (GL_TRANSACTION_SUM GL_JRNL_DETAILS);
  run;

%end;

/* REGISTER NEW_DIMENSION StageDDS Tables */
%let libname=&_stageDDSLib;

%let stgprefix=STAGE_;
%let sesetl_sasLibrary = &libname ;
%let sesetl_registerTables = work._registerTables ;
%let sesetl_version = DDS SAS Supplied Model - v1.2 ;
%let sesetl_treeName = Staging Tables;
%let sesetl_validTreeTypes = D:Dimension Tables @ R:Reference Tables @ F:Fact Tables ;
%let sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree;
%let sesetl_altEtlStudioGroupNm=Data Integration Studio Groups;
%let sesetl_security = Y ;

data &sesetl_registerTables ;
  length sasTableName    $255 ;
  length omrObjTableName $255 ;
  length treeType        $10 ;

  sasTableName    = "&NEW_DIMENSION";
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "&NEW_DIMENSION._ASSOC";
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "&NEW_DIMENSION._ASSOC_TYPE";
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;
run;
proc display c=sashelp.regdata.RegisterSASDataSets.scl;
run;

%if "&ADD_TO_FACT_TABLE" eq "Yes" %then %do;

  proc metalib;
    omr (library="&libname");
    update_rule (noadd);
    select (GL_TRANSACTION_SUM GL_JRNL_DETAILS);
  run;

%end;

%mend;
