/*-- Copyright (c) 2003 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/
/*
* regdds.sas
* Version 9.1S
* registers DDS tables into the libname passed in via the libname macro var, and into
* the repository specified in the options metarepository assigned prior to calling this code.
*
* for example,
* options metarepository="Detail Data Store";
* %let libname=DDS;
* %regdds;
*
* Copyright (c) 2003, 2004 by SAS Institute Inc., Cary, NC 27513
*/

%macro regdds(_miscDim=Y, dt=%sysfunc(datetime()));

%if %symexist(ddstreename) eq 0 %then %let ddstreename=Detail Data Store (DDS);
%if %symexist(stgprefix) eq 0 %then %let stgprefix=;

%let sesetl_sasLibrary = &libname ;
%let sesetl_registerTables = work._registerTables ;
%let sesetl_version = DDS SAS Supplied Model - v1.2 ;
%let sesetl_treeName = &ddstreename ;
%let sesetl_validTreeTypes = D:Dimension Tables @ R:Reference Tables @ F:Fact Tables ;
%let sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree ;
%let sesetl_altEtlStudioGroupNm=Data Integration Studio Groups ;
%let sesetl_security = Y ;

PROC SQL noprint;

  select format into :_format
  from dictionary.columns
  where upcase(libname) eq upcase("&libname")
    and upcase(memname) eq "DIMENSION_TYPE"
    and upcase(name) eq 'VALID_FROM_DTTM'
  ;

QUIT;
%if %cmpres(&_format) eq DATE9. %then
  %let _processTime=%sysfunc(datepart(&dt));
%else
  %let _processTime=&dt;

data &sesetl_registerTables ;
  length sasTableName    $255 ;
  length omrObjTableName $255 ;
  length treeType        $10 ;

  sasTableName    = "ABSENCE_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ACTION_REASON" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ACTION_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ADDRESS_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ANALYSIS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "ANALYSIS_ASSOC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "ANALYSIS_ASSOC_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "APPLICATION_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "APP_DIMENSION" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "APP_MBR_SELECTION_RULES" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "APP_MEMBER_PROPERTY_MAP" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "APP_PROPERTY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "APP_SCHEMA" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "APP_SELECTION_SET" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "APP_SOURCE_ACCOUNT" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "AUDIT_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "BANKRUPTCY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "BILLING_METHOD" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "BUYER" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "BUYER_LEVEL" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "CAL_DATE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "CAL_DATE_X_TIME_PERIOD" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "CAL_EVENT" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "COMMODITY_CODE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "COMMODITY_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "COMPENSATION" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "COMPENSATION_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "CONGRESS_DISTRICT" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "CONTACT_ROLE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "COST_CENTER" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "COST_CENTER_ASSOC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "COST_CENTER_ASSOC_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "COUNTRY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "COUNTY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "CREDIT_SCORE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "CURRENCY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "CURRENCY_EXCH_RATE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "CURRENCY_EXCH_RATE_SET" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "CURRENCY_EXCH_RATE_SRC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "CURRENCY_EXCH_RATE_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "DELAY_REASON" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "DELIVERY_HEADER" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "DELIVERY_LINE_ITEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "DELIVERY_LINE_ITEM_CATEGORY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "DELIVERY_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "DELIVERY_X_INVOICE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "DEL_LINE_ITEM_X_INV_LINE_ITEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "DIMENSION_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "EDUCATION_LEVEL" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "EEO_CLASS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "EMPLOYEE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "EMPLOYEE_ABSENCE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "EMPLOYEE_ACTION" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "EMPLOYEE_INVOLVEMENT_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "EMPLOYEE_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "EMPLOYEE_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "EMPLOYEE_UNION" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "EMPLOYEE_X_INTERNAL_ORG" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "EMPLOYEE_X_JOB" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "EMPLOYMENT_APPLICATION" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "ETHNICITY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "EXEMPT_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "EXTERNAL_ORG" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "EXTERNAL_ORG_ADDRESS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "EXTERNAL_ORG_ASSOC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "EXTERNAL_ORG_ASSOC_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "EXTERNAL_ORG_CONTACT" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "EXTERNAL_ORG_X_NAICS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "EXTERNAL_ORG_X_SIC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "FACILITY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "FACILITY_ITEMS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "FACILITY_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "FAILURE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "FLSA_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "GENDER" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "GL_ACCOUNT" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "GL_ACCOUNT_ASSOC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "GL_ACCOUNT_ASSOC_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "GL_ACCOUNT_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "GL_JRNL" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "GL_JRNL_DETAILS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "GL_NORMAL_BAL" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "GL_TRANSACTION_SUM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "INDUSTRY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "INTERNAL_ORG" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "INTERNAL_ORG_ASSOC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "INTERNAL_ORG_ASSOC_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "INVOICE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "INVOICE_ITEM_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "INVOICE_LINE_ITEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "INVOICE_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ISO_LEVEL" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ITEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "ITEM_CATEGORY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "ITEM_CATEGORY_ASSOC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "ITEM_CATEGORY_ASSOC_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "ITEM_GROUP" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ITEM_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ITEM_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ITEM_X_COMMODITY_CODE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "JOB" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "JOB_GROUP" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "JOB_POSITION" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "LANGUAGE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "LEGAL_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "MAKE_OR_BUY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "MANUFACTURER" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "MANUFACTURER_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "MANUFACTURER_X_ITEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "MARITAL_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "MEASURE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "MILITARY_EXPERIENCE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "MILITARY_EXPERIENCE_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "M_WBE_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "NAICS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "NMSDC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ORG_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "OUT_OF_BUSINESS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "PAYDEX_SCORE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "PAYMENT" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "PAYMENT_METHOD" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "PAYMENT_TERMS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "PAYMENT_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "PAYMENT_X_INVOICE_LINE_ITEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "PAY_LEVEL" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "PAY_LEVEL_STRUCTURE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "PERIOD_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "POSITION_PERMANENCE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "POSITION_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "PO_LINE_ITEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "PO_LINE_ITEM_X_DEL_LINE_ITEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "PO_LINE_ITEM_X_INV_LINE_ITEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "PO_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "PO_X_DELIVERY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "PO_X_INVOICE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "PROFIT_CENTER" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "PROFIT_CENTER_ASSOC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "PROFIT_CENTER_ASSOC_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "PURCHASE_ORDER" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "QUALITY_ASSESSMENT" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "RECEIPT_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "RECRUITMENT_SOURCE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "REJECTION_REASON" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "RETAINED_EARN_ROLL_FWD_METHOD" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "REVISION_LEVEL" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "SEASON" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "SIC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "SIZE_CODE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "SMALL_BUSINESS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "SOURCE_SYSTEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "SPECIAL_CHARGE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "SPEND_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "STATE_REGION" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "SUPPLIER" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "SUPPLIER_CONTRACT" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "SUPPLIER_ENRICHMENT_DATA" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "SUPPLIER_ENRICHMENT_DATA_SRC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "SUPPLIER_ITEM" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "SUPPLIER_ITEM_X_MANUFACTURER" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "F" ;
  output ;

  sasTableName    = "SUPPLIER_STATUS" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "SUPPLIER_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "TIME_FREQUENCY" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "TIME_PERIOD" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "TIME_PERIOD_ASSOC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "TIME_PERIOD_ASSOC_TYPE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "D" ;
  output ;

  sasTableName    = "TIME_UNIT_OF_MEASURE" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

  sasTableName    = "UPC" ;
  omrObjTableName = strip("&stgprefix." || sasTableName) ;
  treeType        = "R" ;
  output ;

run ;

%if "&_miscDim" eq "Y" %then %do;

PROC SQL noprint;
  create table _misc_dimension_type as
  select *
  from &libname..Dimension_Type a
  where valid_from_dttm lt &_processTime
      %if %cmpres(&_format) eq DATE9. %then %do;
        and (valid_to_dttm ge &_processTime or valid_to_dttm eq .)
      %end;
      %else %do;
        and valid_to_dttm ge &_processTime
      %end;
      and not exists(select table_nm
                     from sashelp.Sas_dimension_Type b
                     where a.table_nm eq b.table_nm
                     )
  ;
QUIT;

data work._registertables_misc(keep=sasTableName--treeType);
  length sasTableName    $255 ;
  length omrObjTableName $255 ;
  length treeType        $10 ;

  set _misc_dimension_type end=eof;

  if exist("&libname.." !! strip(table_nm)) then do;
    sasTableName    = table_nm ;
    omrObjTableName = strip("&stgprefix." || sasTableName) ;
    treeType        = "D" ;
    output ;
    sasTableName    = Assoc_table_nm ;
    omrObjTableName = strip("&stgprefix." || sasTableName) ;
    treeType        = "D" ;
    output ;
    sasTableName    = Assoc_Type_table_nm ;
    omrObjTableName = strip("&stgprefix." || sasTableName) ;
    treeType        = "D" ;
    output ;
  end;
run;

proc append base=&sesetl_registerTables data=work._registertables_misc;
run;

%end;

filename _temp temp;
data _null_;
  length _line $256;
  file _temp noprint;
  set &sesetl_registerTables ;
  _line = '%sesdelob(PhysicalTable, PhysicalTable[@Name=''' !! strip(omrObjTableName)
                !! '''][TablePackage/SASLibrary[@Libref=''' !! strip("&libname")
                !! ''']], sesdelob_putlog=NO, sesdelob_warnings=NO);';
  put _line;
run;
%inc _temp;
filename _temp;

proc display c=sashelp.regdata.RegisterSASDataSets.scl;
run;

%mend;
