/*--------------------------------------------------------------
 *  Copyright (c) 2003 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *  NAME:      RegMETA.sas
 *
 *  PURPOSE:   Registers in OMR metadata on PhysicalTable object and associated columns.
 *             Also, registers metadata on the tables indexes and primary keys.  All of this
 *             information is derived directly from the physical data set.  If a libname
 *             to the physical table does not exist, this process will attempt to submit
 *             a valid libname using metadata derived from the SASLibrary object in OMR
 *             and the associated database schema object.
 *
 *             Lastly, this process registers an association to the PhysicalTable into
 *             the metadata tree and associations to Timestamp objects identifying the model
 *             version.
 *
 *
 *
 *  USAGE:
 *
 *  sesetl_serverContext        - Name of OMR ServerContext object (typically IOM Server) associated
 *                                to SASLibrary object
 *  sesetl_sasLibrary           - Name of OMR SASLibrary object associated to (SAS Data set) physicalTable object
 *  sesetl_treeNm               - Associates the TreeNm to the given Software Component.  If the TreeNm does not exist
 *                                one is created.(e.g. Fact Tables)
 *  sesetl_databaseSchema       - Only required for relational tables, name of OMR DatabaseSchema object
 *                                associated to physicalTable object
 *  sesetl_sasLibraryRelational - Name of OMR SASLibrary object associated to (relational tables) physicalTable object
 *  sesetl_propertySetNm        - Required for relational tables, name of DBMS PropertySet
 *
 *  EXAMPLE:
 *


       %regMETA(sesetl_serverContext=IOM Server,
               sesetl_sasLibrary=Conform,
               sesetl_treeNm=Solutions Data Mart (SDM),
               sesetl_databaseSchema=Schema: SASCDM,
               sesetl_sasLibraryRelational=SASCDM,
               sesetl_propertySetNm=DBMSNames
                );


 *
 *
 *  NOTES:
 *
 *-------------------------------------------------------------*/

%macro regMETA(sesetl_serverContext=,
               sesetl_sasLibrary=,
               sesetl_treeNm=Solutions Data Mart (SDM),
               sesetl_databaseSchema=,
               sesetl_sasLibraryRelational=,
               sesetl_propertySetNm=DBMSNames
              );


%let sesetl_sasLibrary = &sesetl_sasLibraryRelational ;
%let sesetl_registerTables = work._registerTables ;
%let sesetl_Version = SDM SAS Supplied Model - v1.0 ;
%let sesetl_ValidTreeTypes = D:Dimension Tables @ R:Reference Tables @ F:Fact Tables ;
%let sesetl_treeName = &sesetl_treeNm ;
%let sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree;
%let sesetl_altEtlStudioGroupNm=Data Integration Studio Groups;
%let sesetl_security = Y ;


data &sesetl_registerTables ;
  length sasTableName    $255 ;
  length omrObjTableName $255 ;
  length treeType        $1 ;

  sasTableName    = "object_type_keygen" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "source_system" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "source_system_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "group_actions" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "dim_mbr_actions" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "role_actions" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "user_actions" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ALERTS" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "ALERT_CRITERIA" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "attachment" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "MEASURE" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "USER_X_MEMBER" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "USERS" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "GROUPS" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "USER_X_GROUP" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "user_x_group_x_jumps" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "USER_PREFERENCES" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "USERANDROLECELLSECURITY" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "fiscal_calendar" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "audit" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "audit_entry" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "comments" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "authtokens" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "objectid" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "process" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "processace" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "status" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "processcurrentstatus" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "processtimer" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "processtimereventattr" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "operand" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "operandace" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "statusace" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "policy" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "policyace" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "policyeventattribute" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "scheduledtimer" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "jmsstate" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "jmsstore" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "version_data" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;



run ;


proc display c=sashelp.regdata.RegisterRelationalTables.scl;
run;



%mend;
