/*--------------------------------------------------------------
 *  Copyright (c) 2003 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *  NAME:      regmetaf.sas
 *
 *  PURPOSE:   For FM application tables,
 *             Registers in OMR metadata on PhysicalTable object and associated columns.
 *             Also, registers metadata on the tables indexes and primary keys.  All of this
 *             information is derived directly from the physical data set.  If a libname
 *             to the physical table does not exist, this process will attempt to submit
 *             a valid libname using metadata derived from the SASLibrary object in OMR
 *             and the associated database schema object.
 *
 *             Lastly, this process registers an association to the PhysicalTable into
 *             the metadata tree and associations to Timestamp objects identifying the model
 *             version.
 *
 *
 *
 *  USAGE:
 *
 *  sesetl_serverContext        - Name of OMR ServerContext object (typically IOM Server) associated
 *                                to SASLibrary object
 *  sesetl_sasLibrary           - Name of OMR SASLibrary object associated to (SAS Data set) physicalTable object
 *  sesetl_treeNm               - Associates the TreeNm to the given Software Component.  If the TreeNm does not exist
 *                                one is created.(e.g. Fact Tables)
 *  sesetl_databaseSchema       - Only required for relational tables, name of OMR DatabaseSchema object
 *                                associated to physicalTable object
 *  sesetl_sasLibraryRelational - Name of OMR SASLibrary object associated to (relational tables) physicalTable object
 *  sesetl_propertySetNm        - Required for relational tables, name of DBMS PropertySet
 *
 *  EXAMPLE:
 *


       %regmetaf(sesetl_serverContext=IOM Server,
                 sesetl_sasLibrary=Conform,
                 sesetl_treeNm=Solutions Data Mart (SDM),
                 sesetl_databaseSchema=Schema: SASCDM,
                 sesetl_sasLibraryRelational=SASCDM,
                 sesetl_propertySetNm=DBMSNames
                );


 *
 *
 *  NOTES:
 *
 *-------------------------------------------------------------*/

%macro regmetaf(sesetl_serverContext=,
                sesetl_sasLibrary=,
                sesetl_treeNm=Solutions Data Mart (SDM),
                sesetl_databaseSchema=,
                sesetl_sasLibraryRelational=,
                sesetl_propertySetNm=DBMSNames
              );

options metarepository="&FinRepos";

%let sesetl_sasLibrary = &sesetl_sasLibraryRelational ;
%let sesetl_registerTables = work._registerTables ;
%let sesetl_Version = SDM SAS Supplied Model - v1.0 ;
%let sesetl_ValidTreeTypes = D:Dimension Tables @ R:Reference Tables @ F:Fact Tables ;
%let sesetl_treeName = &sesetl_treeNm ;
%let sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree;
%let sesetl_altEtlStudioGroupNm=Data Integration Studio Groups;
%let sesetl_security = Y ;


data &sesetl_registerTables ;
  length sasTableName    $255 ;
  length omrObjTableName $255 ;
  length treeType        $1 ;

  sasTableName    = "adjustment_rule" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "allc_mem_selection" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "allc_src_props" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "allocation" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "allocation_cycle" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "balancing_rule" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "cash_inf_trans" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "composite_result" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "composite_x_result" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "cycle_data" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "cycle_x_analysis" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "cycle_x_currency" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "cycle_x_dimension" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "cycle_x_exch_group" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "cycle_x_prate_group" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "data_load" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "disposal_trans" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "dividend_trans" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "eq_fcmi_accts" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "equity_assignment" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "form" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "form_set" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "form_set_x_anlysis" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "form_template" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "form_x_author" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "form_x_reviewer" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "hold_mth_x_time" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "holding" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "line_item" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "manual_adjustment" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "member_group" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "member_selection_rules" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "other_cpo_lineitem" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "other_cpo_trans" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "ownership_rule" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "period" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "purchase_differential" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "purchase_trans" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "result_model" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "result_x_rule" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "result_x_write_mem" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "standalone_parent" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;



run ;


proc display c=sashelp.regdata.RegisterRelationalTables.scl;
run;



%mend;
