/*--------------------------------------------------------------
 *  Copyright (c) 2003 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *  NAME:      RegMetaO.sas
 *
 *  PURPOSE:   For ODCS tables,
 *             Registers in OMR metadata on PhysicalTable object and associated columns.
 *             Also, registers metadata on the tables indexes and primary keys.  All of this
 *             information is derived directly from the physical data set.  If a libname
 *             to the physical table does not exist, this process will attempt to submit
 *             a valid libname using metadata derived from the SASLibrary object in OMR
 *             and the associated database schema object.
 *
 *             Lastly, this process registers an association to the PhysicalTable into
 *             the metadata tree and associations to Timestamp objects identifying the model
 *             version.
 *
 *
 *
 *  USAGE:
 *
 *  sesetl_serverContext        - Name of OMR ServerContext object (typically IOM Server) associated
 *                                to SASLibrary object
 *  sesetl_sasLibrary           - Name of OMR SASLibrary object associated to (SAS Data set) physicalTable object
 *  sesetl_treeNm               - Associates the TreeNm to the given Software Component.  If the TreeNm does not exist
 *                                one is created.(e.g. Fact Tables)
 *  sesetl_databaseSchema       - Only required for relational tables, name of OMR DatabaseSchema object
 *                                associated to physicalTable object
 *  sesetl_sasLibraryRelational - Name of OMR SASLibrary object associated to (relational tables) physicalTable object
 *  sesetl_propertySetNm        - Required for relational tables, name of DBMS PropertySet
 *
 *  EXAMPLE:
 *


       %regMetaO(sesetl_serverContext=IOM Server,
               sesetl_sasLibrary=Conform,
               sesetl_treeNm=Solutions Data Mart (SDM),
               sesetl_databaseSchema=Schema: SASCDM,
               sesetl_sasLibraryRelational=SASCDM,
               sesetl_propertySetNm=DBMSNames
                );


 *
 *
 *  NOTES:
 *
 *-------------------------------------------------------------*/

%macro regMetaO(sesetl_serverContext=,
               sesetl_sasLibrary=,
               sesetl_treeNm=Solutions Data Mart (SDM),
               sesetl_databaseSchema=,
               sesetl_sasLibraryRelational=,
               sesetl_propertySetNm=DBMSNames
              );


%let sesetl_sasLibrary = &sesetl_sasLibraryRelational ;
%let sesetl_registerTables = work._registerTables ;
%let sesetl_Version = SDM SAS Supplied Model - v1.0 ;
%let sesetl_ValidTreeTypes = D:Dimension Tables @ R:Reference Tables @ F:Fact Tables ;
%let sesetl_treeName = &sesetl_treeNm ;
%let sesetl_altETLStudioTreeNm=SAS Data Integration Studio Custom Tree;
%let sesetl_altEtlStudioGroupNm=Data Integration Studio Groups ;
%let sesetl_security = Y ;


data &sesetl_registerTables ;
  length sasTableName    $255 ;
  length omrObjTableName $255 ;
  length treeType        $1 ;

  sasTableName    = "locale" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "dimension_type" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "dimension_type_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "member" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "member_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "hierarchy" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "hierarchy_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "dimension" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "dimension_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "dflt_hier_member" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "child_parent" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "property" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "property_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "member_property" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "hierarchy_property" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "dimension_property" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "dim_type_property" ;
  omrObjTableName = sasTableName ;
  treeType        = "D" ;
  output ;

  sasTableName    = "fact_set" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "fact_set_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "fact_set_dim_type" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "fact" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "vcube" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "vcube_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "vcube_fact_set" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "vcube_hierarchy" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "vcube_property" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "formula" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "formula_operand" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "md_dataload" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "etl_child_parent" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "etl_dflt_hier_member" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "etl_hierarchy" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "etl_member" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "etl_member_property" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "etl_dimension_type" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "etl_exchng_rate" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "etl_property" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "etl_report" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "config" ;
  omrObjTableName = sasTableName ;
  treeType        = "R" ;
  output ;

  sasTableName    = "formula_target" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "prate" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "prate_group" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "prate_group_lookthru" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "prate_group_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "prate_group_precedence" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "prate_set" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "prate_set_dim_type" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "prate_set_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "vcube_prate_group" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "vcube_xrate_group" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "xrate" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "xrate_group" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "xrate_group_lookthru" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "xrate_group_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "xrate_group_precedence" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "xrate_group_target_currency" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "xrate_set" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "xrate_set_dim_type" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;

  sasTableName    = "xrate_set_nls" ;
  omrObjTableName = sasTableName ;
  treeType        = "F" ;
  output ;



run ;


proc display c=sashelp.regdata.RegisterRelationalTables.scl;
run;



%mend;
